<?php
namespace KenthaElementor;

/**
 * Class Plugin
 *
 * Main Plugin class
 * @since 1.0.0
 */
class Plugin {
 
	/**
	 * Instance
	 *
	 * @since 1.0.0
	 * @access private
	 * @static
	 *
	 * @var Plugin The single instance of the class.
	 */
	private static $_instance = null;
 
	/**
	 * Instance
	 *
	 * Ensures only one instance of the class is loaded or can be loaded.
	 *
	 * @since 1.2.0
	 * @access public
	 *
	 * @return Plugin An instance of the class.
	 */
	public static function instance() {
		if ( is_null( self::$_instance ) ) {
			self::$_instance = new self();
		}
					 
		return self::$_instance;
	}
 
	/**
	 * widget_scripts
	 *
	 * Load required plugin core files.
	 *
	 * @since 1.2.0
	 * @access public
	 */
	public function widget_scripts() {
		// COMPONENTS
		// ==================
		$deps = array('jquery', 'masonry');
		// Owl Carousel
		wp_enqueue_script( 'owl-carousel', plugins_url( 'assets/components/owl-carousel/dist/owl.carousel-min.js' , __FILE__ ), $deps,'2.3.2', true);$deps[] = 'owl-carousel';
		// Owl CSS
		wp_enqueue_style( 'owl-carousel', plugins_url( 'assets/components/owl-carousel/dist/assets/owl.carousel.min.css' , __FILE__ ), false, '2.3.2');
		// Main JS
		wp_enqueue_script( 'kentha-extend', plugins_url( '/assets/js/extend.js', __FILE__ ), $deps, filemtime( __FILE__ ), true );
		// Main CSS
		wp_enqueue_style( 'kentha-elementor', plugins_url( '/assets/css/extend.css', __FILE__ ) );
	}

	/**
	 * enqueue_styles
	 *
	 * Load custom styling.
	 *
	 * @since 1.2.0
	 * @access public
	 */
	public function enqueue_styles() {
		wp_enqueue_style( 'kentha-elementor-admin', plugins_url( '/assets/css/admin.css', __FILE__ ) );
		wp_enqueue_style( 'kentha-elementor-admin-icons', plugins_url( '/assets/font/qt-elementor-icons/styles.css', __FILE__ ) );
		wp_enqueue_style(
			'elementor-editor-dark-mode',
			ELEMENTOR_ASSETS_URL . 'css/editor-dark-mode.css',
			[
				'elementor-editor',
			]
		);
	}

 
	/**
	 * Include Widgets files
	 *
	 * Load widgets files
	 *
	 * @since 1.2.0
	 * @access private
	 */
	private function include_widgets_files() {
		require_once( __DIR__ . '/widgets/_helpers/autocomplete.php' );
		require_once( __DIR__ . '/widgets/_helpers/converter.php' );
		require_once( __DIR__ . '/widgets/_helpers/get-terms-array.php' );
		require_once( __DIR__ . '/widgets/_helpers/query-fields.php' );
		require_once( __DIR__ . '/widgets/_helpers/carousel-fields.php' );
		require_once( __DIR__ . '/widgets/_helpers/slider-fields.php' );
		require_once( __DIR__ . '/widgets/accordion/accordion.php' );
		require_once( __DIR__ . '/widgets/blog/blog.php' );
		require_once( __DIR__ . '/widgets/button/button.php' );

		require_once( __DIR__ . '/widgets/section-caption/section-caption.php' );
		require_once( __DIR__ . '/widgets/cards-grid/cards-grid.php' );
		require_once( __DIR__ . '/widgets/post-carousel/post-carousel.php' );
		require_once( __DIR__ . '/widgets/carousel-multimedia/carousel-multimedia.php' );
		require_once( __DIR__ . '/widgets/post-slider/post-slider.php' );
		require_once( __DIR__ . '/widgets/cover-carousel/cover-carousel.php' );
		require_once( __DIR__ . '/widgets/release-small/release-small.php' );
		require_once( __DIR__ . '/widgets/releases-large/releases-large.php' );
		require_once( __DIR__ . '/widgets/event-featured/event-featured.php' );
		require_once( __DIR__ . '/widgets/event-list/event-list.php' );
		require_once( __DIR__ . '/widgets/gallery/gallery.php' );
		require_once( __DIR__ . '/widgets/gallery-multimedia/gallery-multimedia.php' );
		require_once( __DIR__ . '/widgets/image-slider/image-slider.php' );
		require_once( __DIR__ . '/widgets/3d-header/3d-header.php' );
		require_once( __DIR__ . '/widgets/playlist-custom/playlist-custom.php' );
		require_once( __DIR__ . '/widgets/playlist-album/playlist-album.php' );

		// If Kentha Radio plugin is installed
		if ( function_exists( 'qt_kentharadio_plugin_get_version' ) && function_exists('version_compare') ) {
			if(version_compare( qt_kentharadio_plugin_get_version(), '2.0.0', ">=" )){
				require_once( __DIR__ . '/widgets/appicons/appicons.php' );
				require_once( __DIR__ . '/widgets/button-radio/button-radio.php' );
				require_once( __DIR__ . '/widgets/onair/onair.php' );
				require_once( __DIR__ . '/widgets/schedule/schedule.php' );
				require_once( __DIR__ . '/widgets/radiofeed/radiofeed.php' );
				require_once( __DIR__ . '/widgets/chart-tracklist/chart-tracklist.php' );
				require_once( __DIR__ . '/widgets/upcoming-shows-slider/upcoming-shows-slider.php' );
				require_once( __DIR__ . '/widgets/upcoming-shows-carousel/upcoming-shows-carousel.php' );
			}
		}


		if ( class_exists( 'WooCommerce' ) ) {
			require_once( __DIR__ . '/widgets/product-carousel/product-carousel.php' );
			require_once( __DIR__ . '/widgets/product-slider/product-slider.php' );
			require_once( __DIR__ . '/widgets/products-search/products-search.php' );
			require_once( __DIR__ . '/widgets/singletracks-grid/singletracks-grid.php' );
			require_once( __DIR__ . '/widgets/singletracks-list/singletracks-list.php' );
			require_once( __DIR__ . '/widgets/releases-large/releases-large.php' );
		}
		require_once( __DIR__ . '/widgets/cf7/cf7.php' );
	}
 
	/**
	 * Register Widgets
	 * Register new Elementor widgets.
	 * @since 1.2.0
	 * @access public
	 */
	public function register_widgets() {
		$this->include_widgets_files();
		\Elementor\Plugin::instance()->widgets_manager->register( new Widgets\KenthaElementorAccordion() );
		\Elementor\Plugin::instance()->widgets_manager->register( new Widgets\KenthaElementorBlog() );
		\Elementor\Plugin::instance()->widgets_manager->register( new Widgets\KenthaElementorButton() );
		\Elementor\Plugin::instance()->widgets_manager->register( new Widgets\KenthaElementorSectionCaption() );
		\Elementor\Plugin::instance()->widgets_manager->register( new Widgets\KenthaElementorCardsGrid() );
		\Elementor\Plugin::instance()->widgets_manager->register( new Widgets\KenthaElementorPostCarousel() );
		\Elementor\Plugin::instance()->widgets_manager->register( new Widgets\KenthaElementorPostSlider() );
		\Elementor\Plugin::instance()->widgets_manager->register( new Widgets\KenthaElementorCoverCarousel() );
		\Elementor\Plugin::instance()->widgets_manager->register( new Widgets\KenthaElementorEventFeatured() );
		\Elementor\Plugin::instance()->widgets_manager->register( new Widgets\KenthaElementorEventList() );
		\Elementor\Plugin::instance()->widgets_manager->register( new Widgets\KenthaElementorGallery() );
		\Elementor\Plugin::instance()->widgets_manager->register( new Widgets\KenthaElementorGalleryMultimedia() );
		\Elementor\Plugin::instance()->widgets_manager->register( new Widgets\KenthaElementorImageSlider() );
		\Elementor\Plugin::instance()->widgets_manager->register( new Widgets\KenthaElementor3dHeader() );
		\Elementor\Plugin::instance()->widgets_manager->register( new Widgets\KenthaElementorPlaylistCustom() );
		\Elementor\Plugin::instance()->widgets_manager->register( new Widgets\KenthaElementorPlaylistAlbum() );
		\Elementor\Plugin::instance()->widgets_manager->register( new Widgets\KenthaElementorReleaseSmall() );
		\Elementor\Plugin::instance()->widgets_manager->register( new Widgets\KenthaElementorReleasesLarge() );
		\Elementor\Plugin::instance()->widgets_manager->register( new Widgets\KenthaElementorCarouselMultimedia() );

		// If Kentha Radio plugin is installed
		if ( function_exists( 'qt_kentharadio_plugin_get_version' ) && function_exists('version_compare') ) {
			if(version_compare( qt_kentharadio_plugin_get_version(), '2.0.0', ">=" )){
				\Elementor\Plugin::instance()->widgets_manager->register( new Widgets\KenthaElementorAppIcons() );
				\Elementor\Plugin::instance()->widgets_manager->register( new Widgets\KenthaElementorButtonRadio() );
				\Elementor\Plugin::instance()->widgets_manager->register( new Widgets\KenthaElementorChartTracklist() );
				\Elementor\Plugin::instance()->widgets_manager->register( new Widgets\KenthaElementorOnair() );
				\Elementor\Plugin::instance()->widgets_manager->register( new Widgets\KenthaElementorSchedule() );
				\Elementor\Plugin::instance()->widgets_manager->register( new Widgets\KenthaElementorUpcomingShowsSlider() );
				\Elementor\Plugin::instance()->widgets_manager->register( new Widgets\KenthaElementorUpcomingShowsCarousel() );
				\Elementor\Plugin::instance()->widgets_manager->register( new Widgets\KenthaElementorRadiofeed() );
			}
		}

		if ( class_exists( 'WooCommerce' ) ) {
			\Elementor\Plugin::instance()->widgets_manager->register( new Widgets\KenthaElementorProductCarousel() );
			\Elementor\Plugin::instance()->widgets_manager->register( new Widgets\KenthaElementorProductSlider() );
			\Elementor\Plugin::instance()->widgets_manager->register( new Widgets\KenthaElementorProductsSearch() );
			\Elementor\Plugin::instance()->widgets_manager->register( new Widgets\KenthaElementorSingletracksGrid() );
			\Elementor\Plugin::instance()->widgets_manager->register( new Widgets\KenthaElementorSingletracksList() );
			\Elementor\Plugin::instance()->widgets_manager->register( new Widgets\KenthaElementorReleasesLarge() );
		}
		if(defined('WPCF7_VERSION')){
			\Elementor\Plugin::instance()->widgets_manager->register( new Widgets\KenthaElementorCF7() );
		}
	}

	public function add_elementor_widget_categories($elements_manager ) {
		\Elementor\Plugin::instance()->elements_manager->add_category(
			'Kentha',
			[
				'title' => esc_html__( 'Kentha ', 'plugin-name' ),
				'icon' => 'fa fa-plug',
			]
		);
	}

	public function order_elementor_widget_categories(\Elementor\Elements_Manager $elements_manager ) {
		$category_prefix = 'aaa-';
		$elements_manager->add_category(
			$category_prefix . 'kentha',
			[
				'title' => esc_html__( 'Kentha ', 'plugin-name' ),
				'icon' => 'fa fa-plug',
			]
		);
		//hack into the private $categories member, and reorder it so our stuff is at the top
		$reorder_cats = function() use($category_prefix){
			uksort($this->categories, function($keyOne, $keyTwo) use($category_prefix){
				if(substr($keyOne, 0, 4) == $category_prefix){
					return -1;
				}
				if(substr($keyTwo, 0, 4) == $category_prefix){
					return 1;
				}
				return 0;
			});

		};
		$reorder_cats->call($elements_manager);
	}




	/**
	 * ======================================================
	 * Plugin class constructor
	 * ======================================================
	 */
	public function __construct() {
		//Add category
		add_action( 'elementor/elements/categories_registered', [ $this, 'add_elementor_widget_categories' ], 0 );
		add_action( 'elementor/elements/categories_registered', [ $this, 'order_elementor_widget_categories' ], 0 );
		// Register widget scripts
		add_action( 'elementor/frontend/after_register_scripts', [ $this, 'widget_scripts' ] );
		// Register widgets
		add_action( 'elementor/widgets/register', [ $this, 'register_widgets' ] );
		// custom styling
		add_action('elementor/editor/before_enqueue_scripts', [ $this, 'enqueue_styles' ] );
	
	}
}
 
// Instantiate Plugin Class
Plugin::instance();
