<?php
/**
 * @source  https://developers.elementor.com/elementor-controls/
 * @author  Pro.Radio
 * @package  Elementor Kentha
 * @version  1.0.0
 */


namespace KenthaElementor\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Core\Schemes\Typography;


if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly
require_once( __DIR__ . '/3d-header-function.php' );


class KenthaElementor3dHeader extends Widget_Base {
	public function get_name() {
		return 'kentha-elementor-3dheader'; // need to use same ID in the script js
	}
	public function get_title() {
		return esc_html__( '3D Header', 'elementor-kentha' );
	}
	public function get_icon() {
		return 'kentha-elementor-icons icon-qtelicon-3d-header';
	}
	public function get_categories() {
		return [ 'aaa-kentha' ]; // needs to be registered in _plugin.php
	}

	


	/**
	*	===========================================
	*	Javascript
	*	===========================================
	*/
	public function __construct($data = [], $args = null) {
      parent::__construct($data, $args);
      wp_register_script( 'kentha-elementor-3dheader', plugins_url( '/3dheader.js', __FILE__ ), [ 'jquery', 'elementor-frontend' ], '1.0.0', true );
   	}
 	public function get_script_depends() {
	     return [ 'kentha-elementor-3dheader' ];
	}
	// ===============================



	protected function register_controls() {


		
		/**
		 * ============================================
		 * Section 
		 * Button
		 * ============================================
		 */
		
		$this->start_controls_section(
			'section_functionalities',
			[
				'label' => esc_html__( 'Button settings', 'elementor-kentha' ),
			]
		);

		

			
			if(function_exists('qt_kentharadio_active')){
				$options = [
						false => esc_html__( "No action button", "kentha-elementor"),
						'link' => esc_html__( "Link page", "kentha-elementor"),
						'play' => esc_html__( "Play album", "kentha-elementor"),
						'playradio' => esc_html__( "Play radio channel", "kentha-elementor"),
					];

			} else {
				$options = [
						false => esc_html__( "No action button", "kentha-elementor"),
						'link' => esc_html__( "Link page", "kentha-elementor"),
						'play' => esc_html__( "Play album", "kentha-elementor"),
					];
			}



			$this->add_control(
				'linkto',
				[
					'label' => esc_html__( 'Button function', 'kentha-elementor' ),
					'type' => \Elementor\Controls_Manager::SELECT,
					'multiple' => false,
					'default' => false,
					'options' => $options
				]
			);

			// option 1 - link
			$this->add_control(
				'link',
				[
					'label' => esc_html__( 'Button link', 'elementor-kentha' ),
					'type' => Controls_Manager::TEXT,
					'condition' => [
						'linkto' => 'link',
					],
				]
			);
			// option 2- album
			$this->add_control(
				'radio_id',
				[
					'label' => esc_html__( 'Play a radio channel on click', 'elementor-kentha' ),
					'type' => \Elementor\Controls_Manager::SELECT2,
					'label_block' => true,
					'multiple' => false,
					'options' => elementor_kentha_autocomplete('radiochannel'),
					'condition' => [
						'linkto' => 'playradio',
					],
				]
			);
			// option 3 - album
			$this->add_control(
				'release_id',
				[
					'label' => esc_html__( 'Play music album', 'elementor-kentha' ),
					'type' => \Elementor\Controls_Manager::SELECT2,
					'label_block' => true,
					'multiple' => false,
					'options' => elementor_kentha_autocomplete('release'),
					'condition' => [
						'linkto' => 'play',
					],
				]
			);


			
			$this->add_control(
				'text',
				[
					'label' => esc_html__( 'Button label', 'elementor-kentha' ),
					'type' => Controls_Manager::TEXT,
				]
			);



			$this->add_control(
				'btnstyle',
				[
					'label' => esc_html__( 'Button style', 'elementor-kentha' ),
					'type' => \Elementor\Controls_Manager::SELECT,
					'multiple' => false,
					'options' =>[
						'qt-btn-default' => esc_html__( "Default", "kentha"),
						'qt-btn-primary' 	=>	esc_html__( "Primary", "elementor-kentha"),
						'qt-btn-secondary'	=>	esc_html__( "Secondary", "elementor-kentha"),
						'qt-btn-ghost'	=>	esc_html__( "Ghost", "elementor-kentha"),
					]
				]
			);


			$this->add_responsive_control(
				'btn-pos',
				[
					'label' => esc_html__( 'Position', 'elementor-kentha' ),
					'type' => \Elementor\Controls_Manager::SLIDER,
					'range' => [
						'px' => [
							'min' => 0,
							'max' => 85,
						],
					],
					'devices' => [ 'desktop', 'tablet', 'mobile' ],
					'desktop_default' => [
						'size' => 63,
						'unit' => '%',
					],
					'tablet_default' => [
						'size' => 63,
						'unit' => '%',
					],
					'mobile_default' => [
						'size' => 63,
						'unit' => '%',
					],
					'selectors' => [
						'{{WRAPPER}} .qt-perspectivecard p' => 'top: {{SIZE}}{{UNIT}};',
					],
				]
			);


			$this->add_responsive_control(
				'btn-size',
				[
					'label' => esc_html__( 'Size', 'elementor-kentha' ),
					'type' => \Elementor\Controls_Manager::SLIDER,
					'range' => [
						'px' => [
							'min' => 0,
							'max' => 32,
						],
					],
					'devices' => [ 'desktop', 'tablet', 'mobile' ],
					'desktop_default' => [
						'size' => 13,
						'unit' => 'px',
					],
					'tablet_default' => [
						'size' => 13,
						'unit' => 'px',
					],
					'mobile_default' => [
						'size' => 13,
						'unit' => 'px',
					],
					'selectors' => [
						'{{WRAPPER}} .qt-btn' => 'font-size: {{SIZE}}{{UNIT}};',
					],
				]
			);

			$this->add_responsive_control(
				'btn-padding',
				[
					'label' => esc_html__( 'Buttton padding', 'elementor-kentha' ),
					'type' => Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', 'em', '%' ],
					'selectors' => [
						'{{WRAPPER}} .qt-btn' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',
					]
				]
			);
			
			$this->add_responsive_control(
				'btn-radius',
				[
					'label' => esc_html__( 'Border-radius', 'elementor-kentha' ),
					'type' => \Elementor\Controls_Manager::SLIDER,
					'range' => [
						'px' => [
							'min' => 0,
							'max' => 100,
						],
					],
					'devices' => [ 'desktop', 'tablet', 'mobile' ],
					'desktop_default' => [
						'size' => 2,
						'unit' => 'px',
					],
					'tablet_default' => [
						'size' => 2,
						'unit' => 'px',
					],
					'mobile_default' => [
						'size' => 2,
						'unit' => 'px',
					],
					'selectors' => [
						'{{WRAPPER}} .qt-btn' => 'border-radius: {{SIZE}}{{UNIT}};',
					],
				]
			);
		$this->end_controls_section();




		/**
		*	===========================================
		*	Colors
		*	===========================================
		*/
		$this->start_controls_section(
			'section_button_col',
			[
				'label' => esc_html__( 'Button colors', 'elementor-kentha' ),
			]
		);
			$this->add_control(
				'kentha-btn-bg',
				[
					'label' => esc_html__( 'Background', 'elementor-kentha' ),
					'type' => \Elementor\Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .qt-btn' => 'background-color: {{VALUE}} !important;',
					],
				]
			);
			$this->add_control(
				'kentha-btn-txt',
				[
					'label' => esc_html__( 'Text color', 'elementor-kentha' ),
					'type' => \Elementor\Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .qt-btn' => 'color: {{VALUE}} !important;',
					]
				]
			);
			$this->add_group_control(
				\Elementor\Group_Control_Border::get_type(),
				[
					'name' => 'border',
					'label' => __( 'Border', 'plugin-domain' ),
					'selector' => '{{WRAPPER}} .qt-btn',
				]
			);
		$this->end_controls_section();

		/**
		*	===========================================
		*	Colors hover
		*	===========================================
		*/
		$this->start_controls_section(
			'section_button_col_h',
			[
				'label' => esc_html__( 'Button colors hover', 'elementor-kentha' ),
			]
		);
			$this->add_control(
				'kentha-btn-bgh',
				[
					'label' => esc_html__( 'Background hover', 'elementor-kentha' ),
					'type' => \Elementor\Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .qt-btn:hover' => 'background-color: {{VALUE}} !important;',
					]
				]
			);
			$this->add_control(
				'kentha-btn-bch',
				[
					'label' => esc_html__( 'Border hover', 'elementor-kentha' ),
					'type' => \Elementor\Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .qt-btn:hover' => 'border-color: {{VALUE}} !important;',
					]
				]
			);
			$this->add_control(
				'kentha-btn-txthov',
				[
					'label' => esc_html__( 'Text color hover', 'elementor-kentha' ),
					'type' => \Elementor\Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .qt-btn:hover' => 'color: {{VALUE}} !important;',
					]
				]
			);

		$this->end_controls_section();

		/**
		 * ============================================
		 * Section 
		 * Background
		 * ============================================
		 */
		
		$this->start_controls_section(
			'item_background',
			[
				'label' => esc_html__( 'Background', 'elementor-kentha' ),
			]
		);

			$this->add_control(
				'background1',
				[
					'label' => esc_html__( 'Background', 'elementor-kentha' ).' 1',
					'type' => \Elementor\Controls_Manager::MEDIA,
				]
			);
			$this->add_control(
				'background2',
				[	
					'label' => esc_html__( 'Background', 'elementor-kentha' ).' 2',
					'type' => \Elementor\Controls_Manager::MEDIA,
				]
			);
			$this->add_control(
				'background3',
				[	
					'label' => esc_html__( 'Background', 'elementor-kentha' ).' 3',
					'type' => \Elementor\Controls_Manager::MEDIA,
				]
			);
			$this->add_control(
				'background4',
				[	
					'label' => esc_html__( 'Background', 'elementor-kentha' ).' 2',
					'type' => \Elementor\Controls_Manager::MEDIA,
				]
			);
			$this->add_control(
				'foreground1',
				[	
					'label' => esc_html__( 'Foreground', 'elementor-kentha' ).' 1',
					'type' => \Elementor\Controls_Manager::MEDIA,
				]
			);
			$this->add_control(
				'foreground2',
				[	
					'label' => esc_html__( 'Foreground', 'elementor-kentha' ).' 2',
					'type' => \Elementor\Controls_Manager::MEDIA,
				]
			);
		$this->end_controls_section();

	}

	/**
	*	===========================================
	*	Render
	*	===========================================
	*/
	protected function render() {
		$settings = $this->get_settings_for_display();
		if(function_exists('kentha_elementor_3dheader_function')){
			echo kentha_elementor_3dheader_function( $settings );
		}
		
	}

	
	/* Update 2021 09 15 */
protected function content_template() {}
}