<?php
/**
 * @package WordPress
 * @subpackage kentha
 * @version 1.0.0
 * Prepare query for functions
*/


/**
 * 1. Query preparation
 * ================================================
 * If offset is set, paged is ignored (https://codex.wordpress.org/Class_Reference/WP_Query)
 * so we are preparing the query with correct paged number, but it is not affecting the results now
 * instead we also make a custom offset adding offset parameter with page * results number
 */

$offset = (int)$offset;
if(!is_numeric($offset)) {
	$offset = 0;
}

if(!isset($paged)){
	$paged = 1;
}
if (intval($paged) > 1){
	$offset = intval($offset) + ( intval( $items_per_page) * intval( $paged ) );
}
if(!isset($order)){
	$order = 'DESC';
}

$args = array(
	'post_type' 			=>  $post_type,
	'posts_per_page' 		=> (int)$items_per_page,
	'post_status' 			=> 'publish',
	// 'paged' 				=> $paged,
	'suppress_filters' 		=> false,
	// 'offset' 				=> (int)$offset,
	'hideold'				=> false,
	'ignore_sticky_posts' 	=> 1,
	// 'orderby' 				=> trim( esc_attr($orderby) ),
	// 'order' 				=> trim( esc_attr($order) ),
	// 'meta_key'				=> $meta_key,
	// 'post__not_in'			=> explode(',', trim($exclude) ),
);


if(isset($paged)){
	$args['paged'] =  trim( $paged );
}
if(isset($offset)){
	$args['offset'] =  (int)$offset;
}
if(isset($orderby)){
	$args['orderby'] =  trim( esc_attr($orderby) );
}
if(isset($order)){
	$args['order'] =  trim( esc_attr($order) );
}
if(isset($meta_key)){
	$args['meta_key'] =  trim( esc_attr($meta_key) );
}
if(isset($exclude)){
	$args['post__not_in'] =  explode(',', trim($exclude) );
}




// ========== TAXONOMY FILTERING =================
if( isset($tax_filter)  ){
	if($tax_filter){
		

		if(!is_array($tax_filter)){
			$tax_filter_array = explode(',', trim($tax_filter) );
		} else {
			$tax_filter_array = $tax_filter;
		}

		$tax_atts = array();
		$tax_query = array(
			'relation' => 'AND'
		);
		foreach( $tax_filter_array as $var => $val){
			$tax = explode(':', $val);
			if( array_key_exists(1, $tax)){
				$tax_atts[ trim( $tax[0] ) ] [] = trim( $tax[1] );
			}
		}
		foreach( $tax_atts as $taxname => $termslist ){
			$tax_query[] = array(
				'taxonomy' 	=> trim( $taxname ),
				'field' 	=> 'slug',
				'terms'		=> $termslist,
				'operator'	=> 'IN'
			);
		}
		$args[ 'tax_query'] = $tax_query;
	}
}

/**
 * 
 * ========================================
 * Events query parameters
 * ========================================
 * * Order by date
 * * Hide old if enabled in customizer
 * ========================================
 * 
 */
if($post_type == 'event'){
	$args['orderby'] 	= 'meta_value';
	$args['order']   	= 'ASC';
	$args['meta_key'] 	= 'eventdate';
	// Hide old?
	
	if(false != $hideold){
		$args['meta_query'] = array(
			array(
				'key' 		=> 'eventdate',
				'value' 	=> date('Y-m-d'),
				'compare' 	=> '>=',
				'type' 		=> 'date'
			 )
		);
	}
}
// ========== QUERY BY ID =================
if( isset($include_by_id) ){
	if( $include_by_id ){
		if(!is_array($include_by_id)){
			$include_by_id = explode(",",$include_by_id);
		}
		if(count($include_by_id) > 0){
			$quantity = count($include_by_id);
			$args = array(
				'post__in'=> $include_by_id,
				'post_type' =>  'any',
				'orderby' => 'post__in',
				'posts_per_page' => intval($quantity),
				'ignore_sticky_posts' => 1
			);  
		}
	}
}

// ========== CUSTOM QUERY =================
if( isset($custom_query) ){
	if( $custom_query ){
		$args = array();
		parse_str( $custom_query, $args );
		$args['ignore_sticky_posts']= 1;
		$args['suppress_filters']	= false;
		$args['paged']				= $paged;
		$args['offset'] 			= (int)$offset;
		if( $style !== 'all' ){
			$args['posts_per_page'] = (int)$items_per_page;
		}
	}
}