<?php
/**
 * @source  https://developers.elementor.com/elementor-controls/
 * @author  Pro.Radio
 * @package  Elementor Kentha
 * @version  1.0.0
 */


namespace KenthaElementor\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Core\Schemes\Typography;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly


class KenthaElementorAccordion extends Widget_Base {
	public function get_name() {
		return 'kentha-elementor-accordion'; // need to use same ID in the script js
	}
	public function get_title() {
		return esc_html__( 'Accordion', 'kentha-elementor' );
	}
	public function get_icon() {
		return 'kentha-elementor-icons icon-qtelicon-accordion';
	}
	public function get_categories() {
		return [ 'aaa-kentha' ]; // needs to be registered in _plugin.php
	}

	// JS ============================
	public function __construct($data = [], $args = null) {
      parent::__construct($data, $args);
      wp_register_script( 'kentha-elementor-accordion', plugins_url( '/accordion.js', __FILE__ ), [ 'elementor-frontend' ], '1.0.0', true );
   	}
 	public function get_script_depends() {
	     return [ 'kentha-elementor-accordion' ];
	}
	// ===============================

	protected function register_controls() {
		$this->start_controls_section(
			'kentha_atts',
			[
				'label' => esc_html__( 'Items', 'kentha-elementor' ),
			]
		);
			$repeater = new \Elementor\Repeater();
			$repeater->add_control(
				'title',
				[
					'label' => esc_html__( 'Title', 'kentha-elementor' ),
					'show_label' => false,
					'label_block' => true,
					'placeholder' => esc_html__( 'Title', 'kentha-elementor' ),
					'type' => Controls_Manager::TEXT,
				]
			);
			$repeater->add_control(
				'text',
				[
					'label' => esc_html__( 'Text', 'kentha-elementor' ),
					'show_label' => false,
					'label_block' => true,
					'placeholder' => esc_html__( 'Title', 'kentha-elementor' ),
					'type' => Controls_Manager::TEXT,
				]
			);
			$this->add_control(
				'items',
				[
					'label' => esc_html__( 'List', 'kentha-elementor' ),
					'show_label' => false,
					'type' => \Elementor\Controls_Manager::REPEATER,
					'fields' => $repeater->get_controls()
				]
			);
		$this->end_controls_section();
	}

	/**
	 * Frontend
	 */
	protected function render() {
		$atts = $this->get_settings_for_display();
		$items = $atts['items'];
		if(is_array($items)){
			$id = preg_replace('/[0-9]+/', '', uniqid('qttabs')); 
			if(array_key_exists("title", $items[0])){
				?>
				<ul class="collapsible qt-collapsible" data-collapsible="accordion">
					<?php  
					foreach($items as $item){
						if(array_key_exists("text", $item)){
							?>
							<li>
								<div class="collapsible-header qt-content-primary-dark"><i class="material-icons">add</i><?php echo esc_html($item["title"]); ?></div>
								<div class="collapsible-body qt-paper">
									<div class="qt-paddedcontent">
									<?php  
									if(array_key_exists("text", $item)){
										echo wp_kses( $item['text'], array(), array( '' ) );
									}
									?>
									</div>
								</div>

							</li>
							<?php
						}
					}
					?>
				</ul>
				<?php
			}
		}
	}
	/* Update 2021 09 15 */
protected function content_template() {}
}