<?php
/**
 * @source  https://developers.elementor.com/elementor-controls/
 * @author  Pro.Radio
 * @package  Elementor Kentha
 * @version  1.0.0
 */


namespace KenthaElementor\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Core\Schemes\Typography;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly


class KenthaElementorAppIcons extends Widget_Base {
	public function get_name() {
		return 'kentha-elementor-qt-appicons'; // need to use same ID in the script js
	}
	public function get_title() {
		return __( 'Streaming App Icons', 'kentha-elementor' );
	}
	public function get_icon() {
		return 'kentha-elementor-icons icon-qtelicon-streaming-app-icons';
	}
	public function get_categories() {
		return [ 'aaa-kentha' ]; // needs to be registered in _plugin.php
	}

	protected function register_controls() {
		$this->start_controls_section(
			'section_icons',
			[
				'label' => __( 'Icons', 'kentha-elementor' ),
			]
		);
			$this->add_control(
				'app_blackberry',
				[
					'label' => esc_html__( 'Blackberry', 'kentha-elementor' ),
					'type' => Controls_Manager::TEXT,
				]
			);
			$this->add_control(
				'app_itunes',
				[
					'label' => esc_html__( 'iTunes', 'kentha-elementor' ),
					'type' => Controls_Manager::TEXT,
				]
			);
			$this->add_control(
				'app_winphone',
				[
					'label' => esc_html__( 'Windows', 'kentha-elementor' ),
					'type' => Controls_Manager::TEXT,
				]
			);
			$this->add_control(
				'app_winamp',
				[
					'label' => esc_html__( 'WinAmp', 'kentha-elementor' ),
					'type' => Controls_Manager::TEXT,
				]
			);
			$this->add_control(
				'app_tunein',
				[
					'label' => esc_html__( 'TuneIn', 'kentha-elementor' ),
					'type' => Controls_Manager::TEXT,
				]
			);
			$this->add_control(
				'app_mediaplayer',
				[
					'label' => esc_html__( 'Media Player', 'kentha-elementor' ),
					'type' => Controls_Manager::TEXT,
				]
			);
			$this->add_control(
				'app_android',
				[
					'label' => esc_html__( 'Android', 'kentha-elementor' ),
					'type' => Controls_Manager::TEXT,
				]
			);
			$this->add_control(
				'app_iphone',
				[
					'label' => esc_html__( 'iPhone', 'kentha-elementor' ),
					'type' => Controls_Manager::TEXT,
				]
			);
		$this->end_controls_section();


		/**
		*	===========================================
		*	Button
		*	===========================================
		*/

		$this->start_controls_section(
			'kentha_btn',
			[
				'label' => esc_html__( 'Button style', 'kentha-elementor' ),
			]
		);	
			
			



			$this->add_responsive_control(
				'btn-padding',
				[
					'label' => __( 'Padding', 'kentha-elementor' ),
					'type' => Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', 'em', '%' ],
					'default' =>[
						'top' => 14,
						'right' => 14,
						'bottom' => 14,
						'left' => 14,
						'isLinked' => true,
						],
					'selectors' => [
						'{{WRAPPER}} .qt-btn' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;width:auto;',
					],
				]
			);

			$this->add_group_control(
				\Elementor\Group_Control_Border::get_type(),
				[
					'name' => 'border',
					'label' => esc_html__( 'Border', 'kentha-elementor' ),
					'selector' => '{{WRAPPER}} .qt-btn',
				]
			);

			$this->add_responsive_control(
				'btn-radius',
				[
					'label' => esc_html__( 'Border-radius', 'elementor-kentha' ),
					'type' => \Elementor\Controls_Manager::SLIDER,
					'range' => [
						'px' => [
							'min' => 0,
							'max' => 60,
						],
					],
					'devices' => [ 'desktop', 'tablet', 'mobile' ],
					'desktop_default' => [
						'size' => 2,
						'unit' => 'px',
					],
					'tablet_default' => [
						'size' => 2,
						'unit' => 'px',
					],
					'mobile_default' => [
						'size' => 2,
						'unit' => 'px',
					],
					'selectors' => [
						'{{WRAPPER}} .qt-btn' => 'border-radius: {{SIZE}}{{UNIT}};',
					],
				]
			);
			$this->add_responsive_control(
				'btn-fsize',
				[
					'label' => esc_html__( 'icon size', 'elementor-kentha' ),
					'type' => \Elementor\Controls_Manager::SLIDER,
					'range' => [
						'px' => [
							'min' => 13,
							'max' => 48,
						],
					],
					'devices' => [ 'desktop', 'tablet', 'mobile' ],
					'desktop_default' => [
						'size' => 13,
						'unit' => 'px',
					],
					'tablet_default' => [
						'size' => 13,
						'unit' => 'px',
					],
					'mobile_default' => [
						'size' => 13,
						'unit' => 'px',
					],
					'selectors' => [
						'{{WRAPPER}} .qt-kentharadio-appicons span' => 'width: {{SIZE}}{{UNIT}};height: {{SIZE}}{{UNIT}};',
					],
				]
			);


		$this->end_controls_section();

	}

	/**
	 * Frontend
	 */
	protected function render() {
		$atts = $this->get_settings_for_display();
		$defaults =  array(
			'app_android' => '',
			'app_iphone' => '',
			'app_blackberry' => '',
			'app_itunes' => '',
			'app_winphone' => '',
			'app_winamp' => '',
			'app_tunein' => '',
			'app_mediaplayer' => ''
		);

		// print_r( $atts );
		
		?>
			<p class="qt-center qt-kentharadio-appicons">
			<?php 
			foreach ($defaults as $var => $val){

				if($atts[$var] !== '') {
					echo '<a href="'.esc_url($atts['val']).'" class="qt-btn qt-btn-primary qt-btn-l qt-kentharadio-appicons__btn"><span class="qt-kentharadio-'.$var.'"></span></a>';
				}
			}  
			?>
			</p>
		<?php
	}

	
	/* Update 2021 09 15 */
protected function content_template() {}
}