<?php
/**
 * @source  https://developers.elementor.com/elementor-controls/
 * @author  Pro.Radio
 * @package  Elementor Kentha
 * @version  1.0.0
 */


namespace KenthaElementor\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Core\Schemes\Typography;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

require_once( __DIR__ . '/blog-function.php' );

class KenthaElementorBlog extends Widget_Base {
	public function get_name() {
		return 'kentha-elementor-blog'; // need to use same ID in the script js
	}
	public function get_title() {
		return esc_html__( 'Blog', 'kentha-elementor' );
	}
	public function get_icon() {
		return 'kentha-elementor-icons icon-qtelicon-post-list';
	}
	public function get_categories() {
		return [ 'aaa-kentha' ]; // needs to be registered in _plugin.php
	}

	// JS ============================
	public function __construct($data = [], $args = null) {
      parent::__construct($data, $args);
      wp_register_script( 'kentha-elementor-blog', plugins_url( '/blog.js', __FILE__ ), [ 'elementor-frontend' ], '1.0.0', true );
   	}
 	public function get_script_depends() {
	     return [ 'kentha-elementor-blog' ];
	}
	// ===============================

	protected function register_controls() {
		$this->start_controls_section(
			'kentha_elementor_section_query_global',
			[
				'label' => esc_html__( 'Blog settings', 'kentha-elementor' ),
			]
		);	
			$this->add_control(
				'kentha_design',
				[
					'label' => esc_html__( 'Design', 'kentha-elementor' ),
					'type' => \Elementor\Controls_Manager::SELECT,
					'multiple' => false,
					'options' =>[
						false => esc_html__( 'Default', 'kentha' ),
						'split' => esc_html__( 'Horizontal split', 'kentha' ),
						'card' => esc_html__( 'Cards', 'kentha' ),
						'masonry' => esc_html__( 'Masonry', 'kentha' ),
					],
				]
			);
			// Category filtering
			$this->add_control(
				'kel_tax_filter',
				[
					'label' => esc_html__( 'Category filters', 'kentha-elementor' ),
					'type' => \Elementor\Controls_Manager::SELECT2,
					'label_block' => true,
					'multiple' => true,
					'options' => kentha_elementor_get_terms_array('category')
				]
			);
		$this->end_controls_section();
	}

	/**
	 * Frontend
	 */
	protected function render() {
		$atts = $this->get_settings_for_display();
	
		
		if(array_key_exists('kel_tax_filter', $atts)){
			if(is_array($atts['kel_tax_filter'])) {
				$atts['tax_filter'] = implode(',', $atts['kel_tax_filter']);
			}
		}

		
		if(function_exists('kentha_elementor_blog_shortcode')){
			echo kentha_elementor_blog_shortcode( $atts );
		}
	}
	/* Update 2021 09 15 */
protected function content_template() {}
}