<?php
/**
 * @source  https://developers.elementor.com/elementor-controls/
 * @author  Pro.Radio
 * @package  Elementor Kentha
 * @version  1.0.0
 */


namespace KenthaElementor\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Core\Schemes\Typography;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

require_once( __DIR__ . '/cards-grid-function.php' );

class KenthaElementorCardsGrid extends Widget_Base {
	public function get_name() {
		return 'kentha-elementor-cards-grid'; // need to use same ID in the script js
	}
	public function get_title() {
		return esc_html__( 'Post cards grid', 'kentha-elementor' );
	}
	public function get_icon() {
		return 'kentha-elementor-icons icon-qtelicon-post-glass-cards';
	}
	public function get_categories() {
		return [ 'aaa-kentha' ]; // needs to be registered in _plugin.php
	}

	// JS ============================
	public function __construct($data = [], $args = null) {
      parent::__construct($data, $args);
      wp_register_script( 'kentha-elementor-cards-grid', plugins_url( '/cards-grid.js', __FILE__ ), [ 'elementor-frontend' ], '1.0.0', true );
   	}
 	public function get_script_depends() {
	     return [ 'kentha-elementor-cards-grid' ];
	}
	// ===============================


	protected function register_controls() {
		$this->start_controls_section(
			'kentha_elementor_section_query_global',
			[
				'label' => esc_html__( 'Query', 'kentha-elementor' ),
			]
		);	

			$types = [
						"post" => esc_html__( "Posts", 'kentha-elementor' ),
						"podcast" => esc_html__( "Podcast", 'kentha-elementor' ),
						'event' => esc_html__( "Events", 'kentha-elementor' ),
						'artist' => esc_html__( "Artists", 'kentha' ),
						'place' =>esc_html__( "Places", 'kentha' ),
						'release' => esc_html__( "Releases", 'kentha-elementor' ),
						'chart' => esc_html__( "Charts", 'kentha-elementor' ),
					];

			if ( function_exists( 'qt_kentharadio_plugin_get_version' ) ){
				$types['members']  = esc_html__( "Members", 'kentha-elementor' );
			}


			$this->add_control(
				'post_type',
				[
					'label' => esc_html__( 'Post type', 'kentha-elementor' ),
					'type' => \Elementor\Controls_Manager::SELECT,
					'multiple' => false,
					'options' => $types
				]
			);

			
			// $this->add_control(
			// 	'e_loadmore',
			// 	[
			// 		'label' => esc_html__( "Load more button", "kentha" ),
			// 		'type' => Controls_Manager::SWITCHER,
			// 	]
			// );
			

			$this->add_control(
				'iprd',
				[
					'label' => esc_html__( 'Columns per row', 'kentha-elementor' ).' '.esc_html__( 'Desktop', 'kentha-elementor' ),
					'type' => \Elementor\Controls_Manager::SELECT,
					'default' => 3,
					'options' =>[
						1 => esc_html__( "1", "kentha-elementor"),
						2 => esc_html__( "2", "kentha-elementor"),
						3 => esc_html__( "3", "kentha-elementor"),
						4 => esc_html__( "4", "kentha-elementor"),
					]
				]
			);


			$this->add_control(
				'iprt',
				[
					'label' => esc_html__( 'Columns per row', 'kentha-elementor' ).' '.esc_html__( 'Tablet', 'kentha-elementor' ),
					'type' => \Elementor\Controls_Manager::SELECT,
					'default' => 2,
					'options' =>[
						1 => esc_html__( "1", "kentha-elementor"),
						2 => esc_html__( "2", "kentha-elementor"),
						3 => esc_html__( "3", "kentha-elementor"),
						4 => esc_html__( "4", "kentha-elementor"),
					]
				]
			);

		
			$this->add_control(
				'hideold',
				[
					'label' => esc_html__( 'Hide past events', 'kentha-elementor' ),
					'type' => \Elementor\Controls_Manager::SWITCHER,
					'label_on' => esc_html__( 'Hide', 'your-plugin' ),
					'label_off' => esc_html__( 'Show', 'your-plugin' ),
					'return_value' => 'true',
					'default' => false,
					'condition' => [
						'post_type' => 'event'
					],
				]
			);


		

			$this->add_control(
				'kel_tax_filter',
				[
					'label' => esc_html__( 'Category filters', 'kentha-elementor' ),
					'type' => \Elementor\Controls_Manager::SELECT2,
					'label_block' => true,
					'multiple' => true,
					'options' => kentha_elementor_get_terms_array()
				]
			);
		// Fields added by query-fields.php
		$this->end_controls_section();
	}
	/**
	 * Frontend
	 */
	protected function render() {
		$atts = $this->get_settings_for_display();
		if(array_key_exists('kel_tax_filter', $atts)){
			if(is_array($atts['kel_tax_filter'])) {
				$atts['tax_filter'] = implode(',', $atts['kel_tax_filter']);
			}
		}

		if(function_exists('kentha_elementor_card_grid_shortcode')){
			echo kentha_elementor_card_grid_shortcode( $atts );
		}
	}
	/* Update 2021 09 15 */
protected function content_template() {}
}