<?php
/**
 * @source  https://developers.elementor.com/elementor-controls/
 * @author  Pro.Radio
 * @package  Elementor Kentha
 * @version  1.0.0
 */


namespace KenthaElementor\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Core\Schemes\Typography;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

require_once( __DIR__ . '/carousel-multimedia-function.php' );

class KenthaElementorCarouselMultimedia extends Widget_Base {
	public function get_name() {
		return 'kentha-elementor-carousel-multimedia'; // need to use same ID in the script js
	}
	public function get_title() {
		return esc_html__( 'Media carousel', 'kentha-elementor' );
	}
	public function get_icon() {
		return 'kentha-elementor-icons icon-qtelicon-post-carousel';
	}
	public function get_categories() {
		return [ 'aaa-kentha' ]; // needs to be registered in _plugin.php
	}
	// JS ============================	
	public function __construct($data = [], $args = null) {
      parent::__construct($data, $args);
      wp_register_script( 'kentha-elementor-carousel-multimedia', plugins_url( '/media-carousel.js', __FILE__ ), [ 'elementor-frontend' ], '1.0.0', true );
   	}
 	public function get_script_depends() {
	     return [ 'kentha-elementor-carousel-multimedia' ];
	}
	// ===============================

	protected function register_controls() {


		$this->start_controls_section(
			'kentha_atts',
			[
				'label' => esc_html__( 'Items', 'kentha-elementor' ),
			]
		);
			$repeater = new \Elementor\Repeater();
			$repeater->add_control(
				'title',
				[
					'label' => esc_html__( 'Title', 'kentha-elementor' ),
					'show_label' => false,
					'label_block' => true,
					'placeholder' => esc_html__( 'Title', 'kentha-elementor' ),
					'type' => Controls_Manager::TEXT,
				]
			);
			$repeater->add_control(
				'image',
				[
					'label' => esc_html__( 'Choose Image', 'elementor-kentha' ),
					'type' => \Elementor\Controls_Manager::MEDIA,
					'default' => [
						'url' => \Elementor\Utils::get_placeholder_image_src(),
					]
				]
			);
			$repeater->add_control(
				'link',
				[
					'label' =>esc_html__( "Youtube / Vimeo video URL or external link", "kentha-elementor" ),
					'show_label' => true,
					'label_block' => true,
					'placeholder' => esc_html__( 'Link', 'kentha-elementor' ),
					'type' => Controls_Manager::TEXT,
				]
			);
			$this->add_control(
				'items',
				[
					'label' => esc_html__( 'Items', 'kentha-elementor' ),
					'show_label' => false,
					'type' => \Elementor\Controls_Manager::REPEATER,
					'fields' => $repeater->get_controls()
				]
			);
		$this->end_controls_section();



		$this->start_controls_section(
			'kentha_settings',
			[
				'label' => esc_html__( 'Settings', 'kentha-elementor' ),
			]
		);	
	
			$this->add_control(
				'thumbsize',
				[
					'label' => esc_html__( 'Image size', 'kentha-elementor' ),
					'type' => \Elementor\Controls_Manager::SELECT,
					'multiple' => false,
					'default' => 'm',
					'options' =>[
						's' => esc_html__( "Small", "kentha-elementor"),
						'm' => esc_html__( "Medium", "kentha-elementor"),
						'l' => esc_html__( "Large", "kentha-elementor"),
						'sq' => esc_html__( "Squared", "kentha-elementor"),
					]
				]
			);
			$this->add_control(
				'linksize',
				[
					'label' => esc_html__( 'Linked size', 'kentha-elementor' ),
					'type' => \Elementor\Controls_Manager::SELECT,
					'multiple' => false,
					'default' => 'large',
					'options' =>[
						'medium' => esc_html__( "Medium", "kentha-elementor"),
						'large' => esc_html__( "Large", "kentha-elementor"),
						'full' => esc_html__( "Full", "kentha-elementor")
					]
				]
			);
			
		$this->end_controls_section();



		/**
		 * ======================================
		 * Section:
		 * Carousel parameters
		 * ======================================
		 */
		$this->start_controls_section(
			'kentha_elementor_section_carousel_global',
			[
				'label' => esc_html__( 'Settings', 'kentha-elementor' ),
			]
		);

			$this->add_control(
				'title',
				[
					'label' => esc_html__( 'Title', 'elementor-kentha' ),
					'type' => Controls_Manager::TEXT,
				]
			);
		
			// Important::::::::::::::::::::::::::::::::::::
			// Fields added by carousel-fields.php
			// :::::::::::::::::::::::::::::::::::::::::::::
			$this->end_controls_section();



	}

	/**
	 * Frontend
	 */
	protected function render() {
		$atts = $this->get_settings_for_display();
		
		if(function_exists('kentha_elementor_carousel_multimedia_function')){
			echo kentha_elementor_carousel_multimedia_function( $atts );
		}
	}
	/* Update 2021 09 15 */
protected function content_template() {}
}