<?php
/**
 * @source  https://developers.elementor.com/elementor-controls/
 * @author  Pro.Radio
 * @package  Elementor Kentha
 * @version  PR.2.0.7
 */


namespace KenthaElementor\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Core\Schemes\Typography;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly


class KenthaElementorChartTracklist extends Widget_Base {
	public function get_name() {
		return 'kentha-elementor-chart-tracklist'; // need to use same ID in the script js
	}
	public function get_title() {
		return esc_html__( 'Chart tracklist', 'kentha-elementor' );
	}
	public function get_icon() {
		return 'kentha-elementor-icons icon-qtelicon-chart-tracklist';
	}
	public function get_categories() {
		return [ 'aaa-kentha' ]; // needs to be registered in _plugin.php
	}

	protected function register_controls() {
		$this->start_controls_section(
			'section_settings',
			[
				'label' => esc_html__( 'Settings', 'kentha-elementor' ),
			]
		);	

			$this->add_control(
				'chart_id',
				[
					'label' => esc_html__( 'Select chart', 'kentha-elementor' ),
					'type' => \Elementor\Controls_Manager::SELECT2,
					'label_block' => true,
					'description' => esc_html__( "If not specified, use the first result", "kenthaelementor" ),
					'multiple' => false,
					'options' => elementor_kentha_autocomplete('chart')
				]
			);

			

			$this->add_control(
				'number',
				[
					'label' => esc_html__( "Number of tracks to display", "kentha" ),
					'description' => esc_html__( "If smaller than the chart tracks, a button to the chart page will appear.", "kenthaelementor" ),
					'type' => Controls_Manager::TEXT,
					'default' => 100
				]
			);

			$this->add_control(
				'showtitle',
				[
					'label' => esc_html__( "Show chart title", "kentha" ),
					'type' => Controls_Manager::SWITCHER,
				]
			);
			
			$this->add_control(
				'showthumbnail',
				[
					'label' => esc_html__( "Display featured image", "kentha" ),
					'type' => Controls_Manager::SWITCHER,
				]
			);
	

			$this->add_control(
				'chartstyle',
				[
					'label' => esc_html__( 'Chart style', 'kentha-elementor' ),
					'type' => \Elementor\Controls_Manager::SELECT,
					'default' => "chart-normal",
					'options' =>[
						"chart-normal" => esc_html__( "Default", "kenthaelementor"),
						"chart-small" => esc_html__( "Compact", "kenthaelementor")
					]
				]
			);

		$this->end_controls_section();
	}

	/**
	 * Frontend
	 */
	protected function render() {
		$atts = $this->get_settings_for_display();
		if(function_exists('qt_kentharadio_chart_tracklist')){
			echo qt_kentharadio_chart_tracklist( $atts );
		}
	}
	/* Update 2021 09 15 */
protected function content_template() {}
}