<?php
/**
 * @source  https://developers.elementor.com/elementor-controls/
 * @author  Pro.Radio
 * @package  Elementor Kentha
 * @version  1.0.0
 */


namespace KenthaElementor\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Core\Schemes\Typography;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

require_once( __DIR__ . '/event-featured-function.php' );

class KenthaElementorEventFeatured extends Widget_Base {
	public function get_name() {
		return 'kentha-elementor-event-featured'; // need to use same ID in the script js
	}
	public function get_title() {
		return esc_html__( 'Event featured', 'kentha-elementor' );
	}
	public function get_icon() {
		return 'kentha-elementor-icons icon-qtelicon-event-featured';
	}
	public function get_categories() {
		return [ 'aaa-kentha' ]; // needs to be registered in _plugin.php
	}

	// Javascript
	public function __construct($data = [], $args = null) {
	  parent::__construct($data, $args);
	  wp_register_script( 'kentha-elementor-event-featured', plugins_url( '/event-featured.js', __FILE__ ), [ 'elementor-frontend' ], '1.0.0', true );
	}
	public function get_script_depends() {
		 return [ 'kentha-elementor-event-featured' ];
	}

	protected function register_controls() {
		$this->start_controls_section(
			'kentha_elementor_section_query_events',
			[
				'label' => esc_html__( 'Query', 'kentha-elementor' ),
			]
		);	

			$this->add_control(
				'include_by_id',
				[
					'label' => esc_html__( 'Specific items by title', 'elementor-kentha' ),
					'type' => \Elementor\Controls_Manager::SELECT2,
					'label_block' => true,
					'multiple' => true,
					'options' => elementor_kentha_autocomplete('event')
				]
			);

			$this->add_control(
				'items_per_page',
				[
					'label' => esc_html__( 'Max items', 'kentha-elementor' ),
					'type' => Controls_Manager::NUMBER,
					'min' => 1,
					'max' => 20,
					'step' => 1,
					'default' => 1
				]
			);
			
			$this->add_control(
				'kel_tax_filter',
				[
					'label' => esc_html__( 'Category filters', 'kentha-elementor' ),
					'type' => \Elementor\Controls_Manager::SELECT2,
					'label_block' => true,
					'multiple' => true,
					'options' => kentha_elementor_get_terms_array('eventtype'),
				]
			);
			$this->add_control(
				'hideold',
				[
					'label' => esc_html__( 'Hide past events', 'kentha-elementor' ),
					'type' => \Elementor\Controls_Manager::SWITCHER,
					'label_on' => esc_html__( 'Hide', 'your-plugin' ),
					'label_off' => esc_html__( 'Show', 'your-plugin' ),
					'return_value' => 'true',
					'default' => false
				]
			);

			$this->add_responsive_control(
				'events_spacing',
				[
					'label' => esc_html__( 'Spacing', 'elementor-kentha' ),
					'type' => \Elementor\Controls_Manager::SLIDER,
					'range' => [
						'px' => [
							'min' => 0,
							'max' => 150,
						],
					],
					'devices' => [ 'desktop', 'tablet', 'mobile' ],
					'desktop_default' => [
						'size' => 20,
						'unit' => 'px',
					],
					'tablet_default' => [
						'size' => 20,
						'unit' => 'px',
					],
					'mobile_default' => [
						'size' => 20,
						'unit' => 'px',
					],
					'selectors' => [
						'{{WRAPPER}} .kentha-elementor-event-featured__item' => 'margin-bottom: {{SIZE}}{{UNIT}};',
					],
				]
			);
			// $this->add_control(
			// 	'countdown',
			// 	[
			// 		'label' => esc_html__( 'Countdown', 'kentha-elementor' ),
			// 		'type' => Controls_Manager::SWITCHER,
			// 		'default' => false,
			// 		'return_value' => 'true',
			// 	]
			// );
			
		$this->end_controls_section();
	}

	/**
	 * Frontend
	 */
	protected function render() {
		$atts = $this->get_settings_for_display();
		if(array_key_exists('kel_tax_filter', $atts)){
			if(is_array($atts['kel_tax_filter'])) {
				$atts['tax_filter'] = implode(',', $atts['kel_tax_filter']);
			}
		}

		if(function_exists('kentha_elementor_event_feat_function')){
			echo kentha_elementor_event_feat_function( $atts );
		}
	}
	/* Update 2021 09 15 */
protected function content_template() {}
}