<?php
/**
 * @source  https://developers.elementor.com/elementor-controls/
 * @author  Pro.Radio
 * @package  Elementor Kentha
 * @version  1.0.0
 */


namespace KenthaElementor\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Core\Schemes\Typography;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

require_once( __DIR__ . '/event-list-function.php' );

class KenthaElementorEventList extends Widget_Base {
	public function get_name() {
		return 'kentha-elementor-event-list'; // need to use same ID in the script js
	}
	public function get_title() {
		return esc_html__( 'Events list', 'kentha-elementor' );
	}
	public function get_icon() {
		return 'kentha-elementor-icons icon-qtelicon-events-list';
	}
	public function get_categories() {
		return [ 'aaa-kentha' ]; // needs to be registered in _plugin.php
	}

	// Javascript
	public function __construct($data = [], $args = null) {
	  parent::__construct($data, $args);
	  wp_register_script( 'kentha-elementor-event-list', plugins_url( '/event-list.js', __FILE__ ), [ 'elementor-frontend' ], '1.0.0', true );
	}
	public function get_script_depends() {
		 return [ 'kentha-elementor-event-list' ];
	}

	protected function register_controls() {
		$this->start_controls_section(
			'kentha_elementor_section_query_events',
			[
				'label' => esc_html__( 'Query', 'kentha-elementor' ),
			]
		);	

			// $this->add_control(
			// 	'e_loadmore',
			// 	[
			// 		'label' => esc_html__( "Load more button", "kentha" ),
			// 		'type' => Controls_Manager::SWITCHER,
			// 	]
			// );
			
			$this->add_control(
				'include_by_id',
				[
					'label' => esc_html__( 'Specific items by title', 'elementor-kentha' ),
					'type' => \Elementor\Controls_Manager::SELECT2,
					'label_block' => true,
					'multiple' => true,
					'options' => elementor_kentha_autocomplete('event')
				]
			);
			$this->add_control(
				'items_per_page',
				[
					'label' => esc_html__( 'Max items', 'kentha-elementor' ),
					'type' => Controls_Manager::NUMBER,
					'min' => 1,
					'max' => 20,
					'step' => 1,
					'default' => 5
				]
			);
			$this->add_control(
				'kel_tax_filter',
				[
					'label' => esc_html__( 'Category filters', 'kentha-elementor' ),
					'type' => \Elementor\Controls_Manager::SELECT2,
					'label_block' => true,
					'multiple' => true,
					'options' => kentha_elementor_get_terms_array('eventtype')
				]
			);
			$this->add_control(
				'hideold',
				[
					'label' => esc_html__( 'Hide old events', 'kentha-elementor' ),
					'type' => Controls_Manager::SWITCHER,
					'return_value' => 'true'
				]
			);
			
		$this->end_controls_section();
	}

	/**
	 * Frontend
	 */
	protected function render() {
		$atts = $this->get_settings_for_display();
		if(array_key_exists('kel_tax_filter', $atts)){
			if(is_array($atts['kel_tax_filter'])) {
				$atts['tax_filter'] = implode(',', $atts['kel_tax_filter']);
			}
		}
		if(function_exists('kentha_elementor_events_list_function')){
			echo kentha_elementor_events_list_function( $atts );
		}
	}
	/* Update 2021 09 15 */
protected function content_template() {}
}