<?php
/**
 * @source  https://developers.elementor.com/elementor-controls/
 * @author  Pro.Radio
 * @package  Elementor Kentha
 * @version  1.0.0
 */


namespace KenthaElementor\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Core\Schemes\Typography;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly


class KenthaElementorGallery extends Widget_Base {
	public function get_name() {
		return 'kentha-elementor-gallery'; // need to use same ID in the script js
	}
	public function get_title() {
		return esc_html__( 'Flex Gallery', 'kentha-elementor' );
	}
	public function get_icon() {
		return 'kentha-elementor-icons icon-qtelicon-flexgallery';
	}
	public function get_categories() {
		return [ 'aaa-kentha' ]; // needs to be registered in _plugin.php
	}

	protected function register_controls() {
		$this->start_controls_section(
			'section_button',
			[
				'label' => esc_html__( 'Gallery', 'kentha-elementor' ),
			]
		);	
			$this->add_control(
				'gallery',
				[
					'label' => esc_html__( 'Add Images', 'kentha-elementor' ),
					'type' => \Elementor\Controls_Manager::GALLERY,
				]
			);
			$this->add_control(
				'thumbsize',
				[
					'label' => esc_html__( 'Image size', 'kentha-elementor' ),
					'type' => \Elementor\Controls_Manager::SELECT,
					'multiple' => false,
					'default' => 'm',
					'options' =>[
						's' => esc_html__( "Small", "kentha-elementor"),
						'm' => esc_html__( "Medium", "kentha-elementor"),
						'l' => esc_html__( "Large", "kentha-elementor"),
						'sq' => esc_html__( "Squared", "kentha-elementor"),
					]
				]
			);
			$this->add_control(
				'linksize',
				[
					'label' => esc_html__( 'Linked size', 'kentha-elementor' ),
					'type' => \Elementor\Controls_Manager::SELECT,
					'multiple' => false,
					'default' => 'large',
					'options' =>[
						'medium' => esc_html__( "Medium", "kentha-elementor"),
						'large' => esc_html__( "Large", "kentha-elementor"),
						'full' => esc_html__( "Full", "kentha-elementor")
					]
				]
			);
			
			$this->add_responsive_control(
				'imageheight',
				[
					'label' => esc_html__( 'Height', 'elementor-kentha' ),
					'type' => \Elementor\Controls_Manager::SLIDER,
					'range' => [
						'px' => [
							'min' => 100,
							'max' => 1200,
						],
					],
					'devices' => [ 'desktop', 'tablet', 'mobile' ],
					'desktop_default' => [
						'size' => 300,
						'unit' => 'px',
					],
					'tablet_default' => [
						'size' => 200,
						'unit' => 'px',
					],
					'mobile_default' => [
						'size' => 100,
						'unit' => 'px',
					],
					'selectors' => [
						'{{WRAPPER}} .qt-flexbin>*>img, {{WRAPPER}} .qt-flexbin>*' => 'height: {{SIZE}}{{UNIT}};',
					],
				]
			);
		$this->end_controls_section();
	}

	/**
	 * Frontend
	 */
	protected function render() {
		$atts = $this->get_settings_for_display();
		if(function_exists('kentha_short_flexgallery')){
			echo kentha_short_flexgallery( $atts );
		}
	}
	/* Update 2021 09 15 */
protected function content_template() {}
}