<?php
/**
 * @source  https://developers.elementor.com/elementor-controls/
 * @author  Pro.Radio
 * @package  Elementor Kentha
 * @version  1.0.0
 */


namespace KenthaElementor\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Core\Schemes\Typography;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

require_once( __DIR__ . '/image-slider-function.php' );

class KenthaElementorImageSlider extends Widget_Base {
	public function get_name() {
		return 'kentha-elementor-image-sliderwidget'; // need to use same ID in the script js
	}
	public function get_title() {
		return esc_html__( 'Image slider', 'kentha-elementor' );
	}
	public function get_icon() {
		return 'kentha-elementor-icons icon-qtelicon-image-slider';
	}
	public function get_categories() {
		return [ 'aaa-kentha' ]; // needs to be registered in _plugin.php
	}


	// JS ============================	
	public function __construct($data = [], $args = null) {
      parent::__construct($data, $args);
      wp_register_script( 'kentha-elementor-image-sliderwidget', plugins_url( '/slider.js', __FILE__ ), [ 'jquery', 'elementor-frontend' ], '1.0.0', true );
   	}
 	public function get_script_depends() {
	     return [ 'kentha-elementor-image-sliderwidget' ];
	}
	// ===============================



	protected function register_controls() {


		$this->start_controls_section(
			'kentha_atts',
			[
				'label' => esc_html__( 'Items', 'kentha-elementor' ),
			]
		);
			$repeater = new \Elementor\Repeater();
			$repeater->add_control(
				'title',
				[
					'label' => esc_html__( 'Title', 'kentha-elementor' ),
					'show_label' => false,
					'label_block' => true,
					'placeholder' => esc_html__( 'Title', 'kentha-elementor' ),
					'type' => Controls_Manager::TEXT,
				]
			);
			$repeater->add_control(
				'desc',
				[
					'label' => esc_html__( 'Description', 'kentha-elementor' ),
					'show_label' => false,
					'label_block' => true,
					'placeholder' => esc_html__( 'Description', 'kentha-elementor' ),
					'type' => Controls_Manager::TEXT,
				]
			);
			$repeater->add_control(
				'image',
				[
					'label' => esc_html__( 'Choose Image', 'elementor-kentha' ),
					'type' => \Elementor\Controls_Manager::MEDIA,
					'default' => [
						'url' => \Elementor\Utils::get_placeholder_image_src(),
					]
				]
			);
			$repeater->add_control(
				'link',
				[
					'label' =>esc_html__( "Link", "kentha-elementor" ),
					'show_label' => true,
					'label_block' => true,
					'placeholder' => esc_html__( 'Link', 'kentha-elementor' ),
					'type' => Controls_Manager::TEXT,
				]
			);
			$repeater->add_control(
				'linkt',
				[
					'label' =>esc_html__( "Link text", "kentha-elementor" ),
					'show_label' => true,
					'label_block' => true,
					'placeholder' => esc_html__( 'Link text', 'kentha-elementor' ),
					'type' => Controls_Manager::TEXT,
				]
			);
			$this->add_control(
				'items',
				[
					'label' => esc_html__( 'Items', 'kentha-elementor' ),
					'show_label' => false,
					'type' => \Elementor\Controls_Manager::REPEATER,
					'fields' => $repeater->get_controls()
				]
			);
		$this->end_controls_section();



		$this->start_controls_section(
			'kentha_settings',
			[
				'label' => esc_html__( 'Settings', 'kentha-elementor' ),
			]
		);	
	
			$this->add_control(
				'size',
				[
					'label' => esc_html__( 'Image size', 'kentha-elementor' ),
					'type' => \Elementor\Controls_Manager::SELECT,
					'multiple' => false,
					'default' => 'm',
					'options' =>[
						's' => esc_html__( "Small", "kentha-elementor"),
						'm' => esc_html__( "Medium", "kentha-elementor"),
						'l' => esc_html__( "Large", "kentha-elementor"),
						'sq' => esc_html__( "Squared", "kentha-elementor"),
					]
				]
			);
			$this->add_control(
				'proportion',
				[
					'label' => esc_html__( 'Slider proportion', 'kentha-elementor' ),
					'type' => \Elementor\Controls_Manager::SELECT,
					'multiple' => false,
					'default' => 'auto',
					'options' =>[
						'auto' => esc_html__( "Fixed (specify below)", "kentha-elementor"),
						'wide' => esc_html__( "Widescreen 16:7", "kentha-elementor"),
						'ultrawide' => esc_html__( "Ultrawide 2:1", "kentha-elementor"),
						'full' => esc_html__( "Fullscreen", "kentha-elementor"),
					]
				]
			);
			$this->add_control(
				'proportionmob',
				[
					'label' => esc_html__( 'Slider proportion mobile', 'kentha-elementor' ),
					'type' => \Elementor\Controls_Manager::SELECT,
					'multiple' => false,
					'default' => 'auto',
					'options' =>[
						'auto' => esc_html__( "Fixed (specify below)", "kentha-elementor"),
						'wide' => esc_html__( "Widescreen 16:7", "kentha-elementor"),
						'ultrawide' => esc_html__( "Ultrawide 2:1", "kentha-elementor"),
						'full' => esc_html__( "Fullscreen", "kentha-elementor"),
					]
				]
			);
			
			$this->add_responsive_control(
				'height',
				[
					'label' => esc_html__( 'Height', 'elementor-kentha' ),
					'type' => \Elementor\Controls_Manager::SLIDER,
					'range' => [
						'px' => [
							'min' => 150,
							'max' => 1200,
						],
					],
					'devices' => [ 'desktop', 'tablet', 'mobile' ],
					'desktop_default' => [
						'size' => 300,
						'unit' => 'px',
					],
					'tablet_default' => [
						'size' => 200,
						'unit' => 'px',
					],
					'mobile_default' => [
						'size' => 100,
						'unit' => 'px',
					],
					'selectors' => [
						'{{WRAPPER}} .kentha-elementor-image-slider, {{WRAPPER}} .kentha-elementor-image-slider .slides ' => 'height: {{SIZE}}{{UNIT}} !important;',
					],
					'condition' => [
						'proportion' => 'auto'
					],
				]
			);


			$this->add_responsive_control(
				'padding',
				[
					'label' => esc_html__( 'Vertical padding', 'elementor-kentha' ),
					'type' => \Elementor\Controls_Manager::SLIDER,
					'range' => [
						'px' => [
							'min' => 0,
							'max' => 1000,
						],
					],
					'devices' => [ 'desktop', 'tablet', 'mobile' ],
					'desktop_default' => [
						'size' => 170,
						'unit' => 'px',
					],
					'tablet_default' => [
						'size' => 70,
						'unit' => 'px',
					],
					'mobile_default' => [
						'size' => 50,
						'unit' => 'px',
					],
					'selectors' => [
						'{{WRAPPER}} .qt-material-slider .slides li .qt-slidecaption .qt-txt ' => 'padding-top: {{SIZE}}{{UNIT}} !important;',
					],
				]
			);
			
		$this->end_controls_section();


		/**
		*	===========================================
		*	Colors
		*	===========================================
		*/
		$this->start_controls_section(
			'section_button_col',
			[
				'label' => esc_html__( 'Button', 'elementor-kentha' ),
			]
		);
			$this->add_control(
				'kentha-btn-bg',
				[
					'label' => esc_html__( 'Background', 'elementor-kentha' ),
					'type' => \Elementor\Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .qt-btn' => 'background-color: {{VALUE}} !important;',
					],
				]
			);
			$this->add_control(
				'kentha-btn-txt',
				[
					'label' => esc_html__( 'Text color', 'elementor-kentha' ),
					'type' => \Elementor\Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .qt-btn' => 'color: {{VALUE}} !important;',
					]
				]
			);
			$this->add_group_control(
				\Elementor\Group_Control_Border::get_type(),
				[
					'name' => 'border',
					'label' => __( 'Border', 'plugin-domain' ),
					'selector' => '{{WRAPPER}} .qt-btn',
				]
			);



			$this->add_responsive_control(
				'btn-size',
				[
					'label' => esc_html__( 'Size', 'elementor-kentha' ),
					'type' => \Elementor\Controls_Manager::SLIDER,
					'range' => [
						'px' => [
							'min' => 0,
							'max' => 32,
						],
					],
					'devices' => [ 'desktop', 'tablet', 'mobile' ],
					'desktop_default' => [
						'size' => 13,
						'unit' => 'px',
					],
					'tablet_default' => [
						'size' => 13,
						'unit' => 'px',
					],
					'mobile_default' => [
						'size' => 13,
						'unit' => 'px',
					],
					'selectors' => [
						'{{WRAPPER}} .qt-btn' => 'font-size: {{SIZE}}{{UNIT}};',
					],
				]
			);

			$this->add_responsive_control(
				'btn-padding',
				[
					'label' => esc_html__( 'Buttton padding', 'elementor-kentha' ),
					'type' => Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', 'em', '%' ],
					'selectors' => [
						'{{WRAPPER}} .qt-btn' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',
					]
				]
			);
			
			$this->add_responsive_control(
				'btn-radius',
				[
					'label' => esc_html__( 'Border-radius', 'elementor-kentha' ),
					'type' => \Elementor\Controls_Manager::SLIDER,
					'range' => [
						'px' => [
							'min' => 0,
							'max' => 100,
						],
					],
					'devices' => [ 'desktop', 'tablet', 'mobile' ],
					'desktop_default' => [
						'size' => 2,
						'unit' => 'px',
					],
					'tablet_default' => [
						'size' => 2,
						'unit' => 'px',
					],
					'mobile_default' => [
						'size' => 2,
						'unit' => 'px',
					],
					'selectors' => [
						'{{WRAPPER}} .qt-btn' => 'border-radius: {{SIZE}}{{UNIT}};',
					],
				]
			);


		$this->end_controls_section();

		/**
		*	===========================================
		*	Colors hover
		*	===========================================
		*/
		$this->start_controls_section(
			'section_button_col_h',
			[
				'label' => esc_html__( 'Button colors hover', 'elementor-kentha' ),
			]
		);


			$this->add_control(
				'kentha-btn-bgh',
				[
					'label' => esc_html__( 'Background hover', 'elementor-kentha' ),
					'type' => \Elementor\Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .qt-btn:hover' => 'background-color: {{VALUE}} !important;',
					]
				]
			);
			$this->add_control(
				'kentha-btn-bch',
				[
					'label' => esc_html__( 'Border hover', 'elementor-kentha' ),
					'type' => \Elementor\Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .qt-btn:hover' => 'border-color: {{VALUE}} !important;',
					]
				]
			);
			$this->add_control(
				'kentha-btn-txthov',
				[
					'label' => esc_html__( 'Text color hover', 'elementor-kentha' ),
					'type' => \Elementor\Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .qt-btn:hover' => 'color: {{VALUE}} !important;',
					]
				]
			);

		$this->end_controls_section();
	}

	/**
	 * Frontend
	 */
	protected function render() {
		$atts = $this->get_settings_for_display();
		
		if(function_exists('kentha_elementor_imageslider_function')){
			echo kentha_elementor_imageslider_function( $atts );
		}
	}
	/* Update 2021 09 15 */
protected function content_template() {}
}