<?php
/**
 * @source  https://developers.elementor.com/elementor-controls/
 * @author  Pro.Radio
 * @package  Elementor Kentha
 * @version  1.0.0
 */


namespace KenthaElementor\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Core\Schemes\Typography;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly


class KenthaElementorOnair extends Widget_Base {
	public function get_name() {
		return 'kentha-elementor-onair'; // need to use same ID in the script js
	}
	public function get_title() {
		return esc_html__( 'Show On Air', 'elementor-kentha' );
	}
	public function get_icon() {
		return 'kentha-elementor-icons icon-qtelicon-shows-onair';
	}
	public function get_categories() {
		return [ 'aaa-kentha' ]; // needs to be registered in _plugin.php
	}

	protected function register_controls() {
		$this->start_controls_section(
			'section_settings',
			[
				'label' => esc_html__( 'Settings', 'elementor-kentha' ),
			]
		);
			$this->add_responsive_control(
				'kentha-captionsize',
				[
					'label' => esc_html__( 'Caption size', 'elementor-kentha' ),
					'type' => \Elementor\Controls_Manager::SLIDER,
					'range' => [
						'px' => [
							'min' => 20,
							'max' => 90,
						],
					],
					'devices' => [ 'desktop', 'tablet', 'mobile' ],
					'desktop_default' => [
						'size' => 45,
						'unit' => 'px',
					],
					'tablet_default' => [
						'size' => 37,
						'unit' => 'px',
					],
					'mobile_default' => [
						'size' => 27,
						'unit' => 'px',
					],
					'selectors' => [
						'{{WRAPPER}} .qt-fontsize-h0  ' => 'font-size: {{SIZE}}{{UNIT}};',
					],
				]
			);


			$this->add_responsive_control(
				'kentha-sliderheigh',
				[
					'label' => esc_html__( 'Height', 'elementor-kentha' ),
					'type' => \Elementor\Controls_Manager::SLIDER,
					'range' => [
						'px' => [
							'min' => 30,
							'max' => 1200,
						],
					],
					'devices' => [ 'desktop', 'tablet', 'mobile' ],
					'desktop_default' => [
						'size' => 470,
						'unit' => 'px',
					],
					'tablet_default' => [
						'size' => 360,
						'unit' => 'px',
					],
					'mobile_default' => [
						'size' => 380,
						'unit' => 'px',
					],
					'selectors' => [
						'{{WRAPPER}} .qt-kentharadio-show ' => 'padding-top: {{SIZE}}{{UNIT}};',
					],
				]
			);


			
			$this->add_control(
				'schedulefilter',
				[
					'label' => esc_html__( 'Schedule filter', 'kentha-elementor' ),
					'type' => \Elementor\Controls_Manager::SELECT2,
					'label_block' => true,
					'options' => kentha_elementor_get_terms_array('schedulefilter')
				]
			);
		$this->end_controls_section();
	}

	/**
	 * Frontend
	 */
	protected function render() {
		$atts = $this->get_settings_for_display();
		if(array_key_exists('schedulefilter', $atts)){
			if(is_array($atts['schedulefilter'])) {
				$atts['schedulefilter'] = implode(',', $atts['schedulefilter']);
			}
		}
		if(function_exists('qt_kentharadio_onair')){
			echo qt_kentharadio_onair( $atts );
		}
	}
	
	/* Update 2021 09 15 */
protected function content_template() {}
}