<?php
/**
 * @source  https://developers.elementor.com/elementor-controls/
 * @author  Pro.Radio
 * @package  Elementor Kentha
 * @version  1.0.0
 */


namespace KenthaElementor\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Core\Schemes\Typography;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly


class KenthaElementorPlaylistAlbum extends Widget_Base {
	public function get_name() {
		return 'kentha-elementor-playlist-album'; // need to use same ID in the script js
	}
	public function get_title() {
		return esc_html__( 'Release playlist', 'kentha-elementor' );
	}
	public function get_icon() {
		return 'kentha-elementor-icons icon-qtelicon-playlist-album';
	}
	public function get_categories() {
		return [ 'aaa-kentha' ]; // needs to be registered in _plugin.php
	}

	protected function register_controls() {

		$this->start_controls_section(
			'kentha_playlist',
			[
				'label' => esc_html__( 'Playlist album', 'kentha-elementor' ),
			]
		);

			$this->add_responsive_control(
				'title-size',
				[
					'label' => esc_html__( 'Titles size', 'elementor-kentha' ),
					'type' => \Elementor\Controls_Manager::SLIDER,
					'range' => [
						'rem' => [
							'min' => 0.9,
							'max' => 1.7,
						],
					],
					'devices' => [ 'desktop', 'tablet', 'mobile' ],
					'desktop_default' => [
						'size' => 1.2,
						'unit' => 'rem',
					],
					'tablet_default' => [
						'size' => 1.2,
						'unit' => 'rem',
					],
					'mobile_default' => [
						'size' => 1.2,
						'unit' => 'rem',
					],
					'selectors' => [
						'{{WRAPPER}} .qt-playlist-large ul.qt-playlist li .qt-tit' => 'font-size: {{SIZE}}{{UNIT}};height: {{SIZE}}{{UNIT}};',
					],
				]
			);

			/**
			*	===========================================
			*	Repeater
			*	===========================================
			*/
			$repeater = new \Elementor\Repeater();

				/**
				*	===========================================
				*	Repeater fields
				*	===========================================
				*/
				$this->add_control(
				'release_id',
				[
					'label' => esc_html__( 'Choose release by name', 'elementor-kentha' ),
					'type' => \Elementor\Controls_Manager::SELECT2,
					'label_block' => true,
					'multiple' => false,
					'options' => elementor_kentha_autocomplete('release')
				]
			);

		$this->end_controls_section();

		
	}

	/**
	 * Frontend
	 */
	protected function render() {
		$atts = $this->get_settings_for_display();
		extract( shortcode_atts( array(
			'release_id' => false,
		), $atts ) );
		if ($release_id ) {
			?>
			<div class="qt-playlist-large">
				<ul class="qt-playlist">
					<?php echo kentha_playlist_by_id($release_id); ?>
				</ul>
			</div>
			<?php  
		}
	}
	/* Update 2021 09 15 */
protected function content_template() {}
}