<?php
/**
 * @source  https://developers.elementor.com/elementor-controls/
 * @author  Pro.Radio
 * @package  Elementor Kentha
 * @version  1.0.0
 */


namespace KenthaElementor\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Core\Schemes\Typography;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

require_once( __DIR__ . '/playlist-custom-function.php' );

class KenthaElementorPlaylistCustom extends Widget_Base {
	public function get_name() {
		return 'kentha-elementor-playlist-custom'; // need to use same ID in the script js
	}
	public function get_title() {
		return esc_html__( 'Playlist', 'kentha-elementor' );
	}
	public function get_icon() {
		return 'kentha-elementor-icons icon-qtelicon-playlist';
	}
	public function get_categories() {
		return [ 'aaa-kentha' ]; // needs to be registered in _plugin.php
	}

	protected function register_controls() {

		$this->start_controls_section(
			'kentha_playlist',
			[
				'label' => esc_html__( 'Playlist', 'kentha-elementor' ),
			]
		);

			$this->add_responsive_control(
				'title-size',
				[
					'label' => esc_html__( 'Titles size', 'elementor-kentha' ),
					'type' => \Elementor\Controls_Manager::SLIDER,
					'range' => [
						'rem' => [
							'min' => 0.9,
							'max' => 1.7,
						],
					],
					'devices' => [ 'desktop', 'tablet', 'mobile' ],
					'desktop_default' => [
						'size' => 1.2,
						'unit' => 'rem',
					],
					'tablet_default' => [
						'size' => 1.2,
						'unit' => 'rem',
					],
					'mobile_default' => [
						'size' => 1.2,
						'unit' => 'rem',
					],
					'selectors' => [
						'{{WRAPPER}} .qt-playlist-large ul.qt-playlist li .qt-tit' => 'font-size: {{SIZE}}{{UNIT}};height: {{SIZE}}{{UNIT}};',
					],
				]
			);
			

			/**
			*	===========================================
			*	Repeater
			*	===========================================
			*/
			$repeater = new \Elementor\Repeater();

				/**
				*	===========================================
				*	Repeater fields
				*	===========================================
				*/
				$repeater->add_control(
					'image',
					[
						'label' => esc_html__( 'Thumbnail', 'elementor-kentha' ). ' 300px',
						'type' => \Elementor\Controls_Manager::MEDIA,
						'default' => [
							'url' => \Elementor\Utils::get_placeholder_image_src(),
						]
					]
				);
				$repeater->add_control(
					'file_link',
					[
						'label' => esc_html__( 'Select File', 'elementor-kentha' ),
						'type'  => 'file-select',
						'placeholder' => esc_html__( 'URL to File', 'elementor-file-select-control' ),
						'description' => esc_html__( 'Select file from media library or upload', 'elementor-file-select-control' ),
					]
				);
				$repeater->add_control(
					'title',
					[
						'label' =>esc_html__( "Title", "kentha-elementor" ),
						'show_label' => true,
						'label_block' => true,
						'placeholder' => esc_html__( 'Link', 'kentha-elementor' ),
						'type' => Controls_Manager::TEXT,
					]
				);
				$repeater->add_control(
					'artist',
					[
						'label' =>esc_html__( "Artist", "kentha-elementor" ),
						'type' => Controls_Manager::TEXT,
						'label_block' => true,
						'multiple' => false,
					]
				);
				$repeater->add_control(
					'album_link',
					[
						'label' =>esc_html__( "Album link", "kentha-elementor" ),
						'show_label' => true,
						'label_block' => true,
						'placeholder' => esc_html__( 'Link', 'kentha-elementor' ),
						'type' => Controls_Manager::TEXT,
					]
				);
				$repeater->add_control(
					'buy_link',
					[
						'label' =>esc_html__( "Buy link", "kentha-elementor" ),
						"description" => esc_html__( "Use numeric ID in case of WooCommerce products", "kentha" ),
						'show_label' => true,
						'label_block' => true,
						'placeholder' => esc_html__( 'Link', 'kentha-elementor' ),
						'type' => Controls_Manager::TEXT,
					]
				);
				$repeater->add_control(
					'icon',
					[
						'label' => esc_html__( 'Icon', 'kentha-elementor' ),
						'type' => \Elementor\Controls_Manager::SELECT,
						'multiple' => false,
						'default' => 'large',
						'options' =>[
							'add_shopping_cart' => esc_html__( "Cart", "kentha-elementor"),
							'file_download' => esc_html__( "Download", "kentha-elementor"),
						]
					]
				);

			// Add repeater
			$this->add_control(
				'items',
				[
					'label' => esc_html__( 'Tracks', 'kentha-elementor' ),
					'show_label' => false,
					'type' => \Elementor\Controls_Manager::REPEATER,
					'fields' => $repeater->get_controls()
				]
			);

		$this->end_controls_section();

		
	}

	/**
	 * Frontend
	 */
	protected function render() {
		$atts = $this->get_settings_for_display();
	


		if(function_exists('kentha_elementor_playlistcustom_function')){
			echo kentha_elementor_playlistcustom_function( $atts );
		}
	}
	/* Update 2021 09 15 */
protected function content_template() {}
}