<?php
/**
 * @source  https://developers.elementor.com/elementor-controls/
 * @author  Pro.Radio
 * @package  Elementor Kentha
 * @version  1.0.0
 */


namespace KenthaElementor\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Core\Schemes\Typography;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly
require_once( __DIR__ . '/post-carousel-function.php' );

class KenthaElementorPostCarousel extends Widget_Base {
	public function get_name() {
		return 'kentha-elementor-post-carousel'; // need to use same ID in the script js
	}
	public function get_title() {
		return esc_html__( 'Post custom carousel', 'kentha-elementor' );
	}
	public function get_icon() {
		return 'kentha-elementor-icons icon-qtelicon-post-carousel';
	}
	public function get_categories() {
		return [ 'aaa-kentha' ]; // needs to be registered in _plugin.php
	}


	// JS ============================	
	public function __construct($data = [], $args = null) {
      parent::__construct($data, $args);
      wp_register_script( 'kentha-elementor-post-carousel', plugins_url( '/post-carousel.js', __FILE__ ), [ 'elementor-frontend' ], '1.0.0', true );
   	}
 	public function get_script_depends() {
	     return [ 'kentha-elementor-post-carousel' ];
	}
	// ===============================

	protected function register_controls() {


		/**
		 * ======================================
		 * Section:
		 * Carousel parameters
		 * ======================================
		 */
		$this->start_controls_section(
			'kentha_elementor_section_carousel_global',
			[
				'label' => esc_html__( 'Settings', 'kentha-elementor' ),
			]
		);

			$this->add_control(
				'title',
				[
					'label' => esc_html__( 'Title', 'elementor-kentha' ),
					'type' => Controls_Manager::TEXT,
				]
			);
		
			// Important::::::::::::::::::::::::::::::::::::
			// Fields added by carousel-fields.php
			// :::::::::::::::::::::::::::::::::::::::::::::
			$this->end_controls_section();









		/**
		 * ======================================
		 * Section:
		 * Query parameters
		 * ======================================
		 */
		$this->start_controls_section(
			'kentha_elementor_section_query_global',
			[
				'label' => esc_html__( 'Query', 'kentha-elementor' ),
			]
		);



			if(function_exists('qt_kentharadio_active')){
				$this->add_control(
					'post_type',
					[
						'label' => esc_html__( 'Post type', 'kentha-elementor' ),
						'type' => \Elementor\Controls_Manager::SELECT,
						'multiple' => false,
						'options' =>[
							"post" => esc_html__( "Posts", 'kentha-elementor' ),
							"podcast" => esc_html__( "Podcast", 'kentha-elementor' ),
							'event' => esc_html__( "Events", 'kentha-elementor' ),
							'artist' => esc_html__( "Artists", 'kentha' ),
							'place' =>esc_html__( "Places", 'kentha' ),
							'release' => esc_html__( "Releases", 'kentha-elementor' ),
							'chart' => esc_html__( "Charts", 'kentha-elementor' ),
							'members' => esc_html__( "Members", 'kentha-elementor' ),
						]
					]
				);
			} else {
				$this->add_control(
					'post_type',
					[
						'label' => esc_html__( 'Post type', 'kentha-elementor' ),
						'type' => \Elementor\Controls_Manager::SELECT,
						'multiple' => false,
						'options' =>[
							"post" => esc_html__( "Posts", 'kentha-elementor' ),
							"podcast" => esc_html__( "Podcast", 'kentha-elementor' ),
							'event' => esc_html__( "Events", 'kentha-elementor' ),
							'artist' => esc_html__( "Artists", 'kentha' ),
							'place' =>esc_html__( "Places", 'kentha' ),
							'release' => esc_html__( "Releases", 'kentha-elementor' ),
						]
					]
				);
			}

			$this->add_control(
				'hideold',
				[
					'label' => esc_html__( 'Hide past events', 'kentha-elementor' ),
					'type' => \Elementor\Controls_Manager::SWITCHER,
					'label_on' => esc_html__( 'Hide', 'your-plugin' ),
					'label_off' => esc_html__( 'Show', 'your-plugin' ),
					'return_value' => 'true',
					'default' => false,
					'condition' => [
						'post_type' => 'event'
					],
				]
			);

			$this->add_control(
				'kel_tax_filter',
				[
					'label' => esc_html__( 'Category filters', 'kentha-elementor' ),
					'type' => \Elementor\Controls_Manager::SELECT2,
					'label_block' => true,
					'multiple' => true,
					'options' => kentha_elementor_get_terms_array('category','tag')
				]
			);
		// Important::::::::::::::::::::::::::::::::::::
		// Fields added by query-fields.php
		// :::::::::::::::::::::::::::::::::::::::::::::
		$this->end_controls_section();

		
	}
	/**
	 * Frontend
	 */
	protected function render() {
		$atts = $this->get_settings_for_display();
		if(array_key_exists('kel_tax_filter', $atts)){
			if(is_array($atts['kel_tax_filter'])) {
				$atts['tax_filter'] = implode(',', $atts['kel_tax_filter']);
			}
		}
		if(function_exists('kentha_elementor_carousel_function')){
			echo kentha_elementor_carousel_function( $atts );
		}
	}
	/* Update 2021 09 15 */
protected function content_template() {}
}