<?php
/**
 * @source  https://developers.elementor.com/elementor-controls/
 * @author  Pro.Radio
 * @package  Elementor Kentha
 * @version  1.0.0
 */


namespace KenthaElementor\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Core\Schemes\Typography;
use Elementor\Control_Dimensions;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

require_once( __DIR__ . '/product-slider-function.php' );

class KenthaElementorProductSlider extends Widget_Base {
	public function get_name() {
		return 'kentha-elementor-product-sliderwidget'; // need to use same ID in the script js
	}
	public function get_title() {
		return esc_html__( 'WooCommerce Product slider', 'kentha-elementor' );
	}
	public function get_icon() {
		return 'kentha-elementor-icons icon-qtelicon-woocommerce-product-slider';
	}
	public function get_categories() {
		return [ 'aaa-kentha' ]; // needs to be registered in _plugin.php
	}


	// JS ============================	
	public function __construct($data = [], $args = null) {
      parent::__construct($data, $args);
      wp_register_script( 'kentha-elementor-product-sliderwidget', plugins_url( '/slider.js', __FILE__ ), [ 'jquery', 'elementor-frontend' ], '1.0.0', true );
   	}
 	public function get_script_depends() {
	     return [ 'kentha-elementor-product-sliderwidget' ];
	}
	// ===============================



	protected function register_controls() {


		/**
		*	===========================================
		*	Design settings
		*	===========================================
		*/




		$this->start_controls_section(
			'kentha_settings',
			[
				'label' => esc_html__( 'Design', 'kentha-elementor' ),
			]
		);	

			$this->add_control(
				'textalign',
				[
					'label' => esc_html__( 'Content alignment', 'kentha-elementor' ),
					'type' => \Elementor\Controls_Manager::SELECT,
					'multiple' => false,
					'default' => 'm',
					'options' =>[
						'' => esc_html__( "Default", "kentha-elementor"),
						'aligncenter' => esc_html__( "Center", "kentha-elementor"),
						'alignleft' => esc_html__( "Left", "kentha-elementor"),
						'alignright' => esc_html__( "Right", "kentha-elementor"),
					]
				]
			);

			$this->add_responsive_control(
				'capsize',
				[
					'label' => esc_html__( 'Caption size', 'elementor-kentha' ),
					'type' => \Elementor\Controls_Manager::SLIDER,
					'range' => [
						'px' => [
							'min' => 16,
							'max' => 90,
						],
					],
					'defaults' => [ 'desktop', 'tablet', 'mobile' ],
					'selectors' => [
						'{{WRAPPER}} .kentha-elementor-product-slider .qt-slidecaption h3' => 'font-size: {{SIZE}}{{UNIT}} !important;',
					],
				]
			);
			$this->add_responsive_control(
				'capmargin',
				[
					'label' => __( 'Caption margins', 'kentha-elementor' ),
					'type' => Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', 'em', '%' ],
					'selectors' => [
						'{{WRAPPER}} .kentha-elementor-product-slider h3' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',
					],
				]
			);
	
			$this->add_control(
				'isize',
				[
					'label' => esc_html__( 'Image size', 'kentha-elementor' ),
					'type' => \Elementor\Controls_Manager::SELECT,
					'multiple' => false,
					'default' => 'large',
					'options' =>[
						'small' => esc_html__( "Small", "kentha-elementor"),
						'medium' => esc_html__( "Medium", "kentha-elementor"),
						'large' => esc_html__( "Large", "kentha-elementor"),
						'full' => esc_html__( "Full", "kentha-elementor"),
						'kentha-squared' => esc_html__( "Squared", "kentha-elementor"),
					]
				]
			);
			$this->add_control(
				'proportion',
				[
					'label' => esc_html__( 'Slider proportion', 'kentha-elementor' ),
					'type' => \Elementor\Controls_Manager::SELECT,
					'multiple' => false,
					'default' => 'auto',
					'options' =>[
						'auto' => esc_html__( "Fixed (specify below)", "kentha-elementor"),
						'wide' => esc_html__( "Widescreen 16:7", "kentha-elementor"),
						'ultrawide' => esc_html__( "Ultrawide 2:1", "kentha-elementor"),
						'full' => esc_html__( "Fullscreen", "kentha-elementor"),
					]
				]
			);
			$this->add_control(
				'proportionmob',
				[
					'label' => esc_html__( 'Slider proportion mobile', 'kentha-elementor' ),
					'type' => \Elementor\Controls_Manager::SELECT,
					'multiple' => false,
					'default' => 'auto',
					'options' =>[
						'auto' => esc_html__( "Fixed (specify below)", "kentha-elementor"),
						'wide' => esc_html__( "Widescreen 16:7", "kentha-elementor"),
						'ultrawide' => esc_html__( "Ultrawide 2:1", "kentha-elementor"),
						'full' => esc_html__( "Fullscreen", "kentha-elementor"),
					]
				]
			);
			
			$this->add_responsive_control(
				'height',
				[
					'label' => esc_html__( 'Height', 'elementor-kentha' ),
					'type' => \Elementor\Controls_Manager::SLIDER,
					'range' => [
						'px' => [
							'min' => 150,
							'max' => 1200,
						],
					],
					'devices' => [ 'desktop', 'tablet', 'mobile' ],
					'desktop_default' => [
						'size' => 300,
						'unit' => 'px',
					],
					'tablet_default' => [
						'size' => 200,
						'unit' => 'px',
					],
					'mobile_default' => [
						'size' => 100,
						'unit' => 'px',
					],
					'selectors' => [
						'{{WRAPPER}} .kentha-elementor-product-slider, {{WRAPPER}} .kentha-elementor-product-slider .slides ' => 'height: {{SIZE}}{{UNIT}} !important;',
					],
					'condition' => [
						'proportion' => 'auto'
					],
				]
			);


			$this->add_responsive_control(
				'padding',
				[
					'label' => esc_html__( 'Vertical padding', 'elementor-kentha' ),
					'type' => \Elementor\Controls_Manager::SLIDER,
					'range' => [
						'px' => [
							'min' => 0,
							'max' => 1000,
						],
					],
					'devices' => [ 'desktop', 'tablet', 'mobile' ],
					'desktop_default' => [
						'size' => 170,
						'unit' => 'px',
					],
					'tablet_default' => [
						'size' => 70,
						'unit' => 'px',
					],
					'mobile_default' => [
						'size' => 50,
						'unit' => 'px',
					],
					'selectors' => [
						'{{WRAPPER}} .qt-material-slider .slides li .qt-slidecaption .qt-txt ' => 'padding-top: {{SIZE}}{{UNIT}} !important;',
					],
				]
			);
			
		$this->end_controls_section();


		

		


		/**
		*	===========================================
		*	Button
		*	===========================================
		*/

		$this->start_controls_section(
			'kentha_button',
			[
				'label' => esc_html__( 'Button styling', 'kentha-elementor' ),
			]
		);	
			
			

			

			$this->add_responsive_control(
				'btn-padding',
				[
					'label' => __( 'Padding', 'kentha-elementor' ),
					'type' => Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', 'em', '%' ],
					'selectors' => [
						'{{WRAPPER}} .qt-btn' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',
					],
				]
			);

			$this->add_group_control(
				\Elementor\Group_Control_Border::get_type(),
				[
					'name' => 'border',
					'label' => esc_html__( 'Border', 'kentha-elementor' ),
					'selector' => '{{WRAPPER}} .qt-btn',
				]
			);

			$this->add_responsive_control(
				'btn-radius',
				[
					'label' => esc_html__( 'Border-radius', 'elementor-kentha' ),
					'type' => \Elementor\Controls_Manager::SLIDER,
					'range' => [
						'px' => [
							'min' => 0,
							'max' => 100,
						],
					],
					'devices' => [ 'desktop', 'tablet', 'mobile' ],
					'desktop_default' => [
						'size' => 2,
						'unit' => 'px',
					],
					'tablet_default' => [
						'size' => 2,
						'unit' => 'px',
					],
					'mobile_default' => [
						'size' => 2,
						'unit' => 'px',
					],
					'selectors' => [
						'{{WRAPPER}} .qt-btn' => 'border-radius: {{SIZE}}{{UNIT}};',
					],
				]
			);
			$this->add_responsive_control(
				'btn-fsize',
				[
					'label' => esc_html__( 'Font size', 'elementor-kentha' ),
					'type' => \Elementor\Controls_Manager::SLIDER,
					'range' => [
						'px' => [
							'min' => 10,
							'max' => 40,
						],
					],
					'devices' => [ 'desktop', 'tablet', 'mobile' ],
					'desktop_default' => [
						'size' => 13,
						'unit' => 'px',
					],
					'tablet_default' => [
						'size' => 13,
						'unit' => 'px',
					],
					'mobile_default' => [
						'size' => 13,
						'unit' => 'px',
					],
					'selectors' => [
						'{{WRAPPER}} .qt-btn' => 'font-size: {{SIZE}}{{UNIT}};',
					],
				]
			);

			$this->add_control(
				'kentha-btn-bg',
				[
					'label' => esc_html__( 'Background', 'elementor-kentha' ),
					'type' => \Elementor\Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .qt-btn' => 'background-color: {{VALUE}} !important;',
					],
				]
			);
			$this->add_control(
				'kentha-btn-txt',
				[
					'label' => esc_html__( 'Text color', 'elementor-kentha' ),
					'type' => \Elementor\Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .qt-btn' => 'color: {{VALUE}} !important;',
					]
				]
			);


		$this->end_controls_section();


		/**
		*	===========================================
		*	Colors hover
		*	===========================================
		*/
		$this->start_controls_section(
			'section_button_col_h',
			[
				'label' => esc_html__( 'Button colors hover', 'elementor-kentha' ),
			]
		);
			$this->add_control(
				'kentha-btn-bgh',
				[
					'label' => esc_html__( 'Background hover', 'elementor-kentha' ),
					'type' => \Elementor\Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .qt-btn:hover' => 'background-color: {{VALUE}} !important;',
					]
				]
			);
			$this->add_control(
				'kentha-btn-bch',
				[
					'label' => esc_html__( 'Border hover', 'elementor-kentha' ),
					'type' => \Elementor\Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .qt-btn:hover' => 'border-color: {{VALUE}} !important;',
					]
				]
			);
			$this->add_control(
				'kentha-btn-txthov',
				[
					'label' => esc_html__( 'Text color hover', 'elementor-kentha' ),
					'type' => \Elementor\Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .qt-btn:hover' => 'color: {{VALUE}} !important;',
					]
				]
			);

		$this->end_controls_section();


		/**
		 * ======================================
		 * Section:
		 * Query parameters
		 * ======================================
		 */
		$this->start_controls_section(
			'kentha_elementor_section_query_global',
			[
				'label' => esc_html__( 'Query', 'kentha-elementor' ),
			]
		);

			$this->add_control(
				'kel_tax_filter',
				[
					'label' => esc_html__( 'Category filters', 'kentha-elementor' ),
					'type' => \Elementor\Controls_Manager::SELECT2,
					'label_block' => true,
					'multiple' => true,
					'options' => kentha_elementor_get_terms_array()
				]
			);
		// Important::::::::::::::::::::::::::::::::::::
		// Fields added by query-fields.php
		// :::::::::::::::::::::::::::::::::::::::::::::
		$this->end_controls_section();
	}




	/**
	 * Frontend
	 */
	protected function render() {
		$atts = $this->get_settings_for_display();
		if(array_key_exists('kel_tax_filter', $atts)){
			if(is_array($atts['kel_tax_filter'])) {
				$atts['tax_filter'] = implode(',', $atts['kel_tax_filter']);
			}
		}
		if(function_exists('kentha_elementor_product_slider_function')){
			echo kentha_elementor_product_slider_function( $atts );
		}
	}
	/* Update 2021 09 15 */
protected function content_template() {}
}