<?php
/**
 * @source  https://developers.elementor.com/elementor-controls/
 * @author  Kentha
 * @package  Elementor Kentha
 * @version  1.0.0
 */


namespace KenthaElementor\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly


class KenthaElementorProductsSearch extends Widget_Base {
	public function get_name() {
		return 'kentha-elementor-products-search'; // need to use same ID in the script js
	}
	public function get_title() {
		return esc_html__( 'WooCommerce Products search', 'kentha-elementor' );
	}
	public function get_icon() {
		return 'kentha-elementor-icons icon-qtelicon-woocommerce-product-search';
	}
	public function get_categories() {
		return [ 'aaa-kentha' ]; // needs to be registered in _plugin.php
	}
	protected function register_controls() {
		$this->start_controls_section(
			'section_settings_form',
			[
				'label' => esc_html__( 'Settings', 'kentha-elementor' ),
			]
		);
			
			$this->add_control(
				'class',
				[
					'label' => esc_html__( 'CSS Class', 'kentha-elementor' ),
					'type' => \Elementor\Controls_Manager::TEXT,
				]
			);
			$this->add_control(
				'placeholder',
				[
					'label' => esc_html__( 'Placeholder', 'kentha-elementor' ),
					'type' => \Elementor\Controls_Manager::TEXT,
					'default' => 'Search: type and hit enter '
				]
			);

			$this->add_control(
				'color_input',
				[
					'label' => esc_html__( 'Background color', 'elementor-kentha' ),
					'type' => \Elementor\Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .kentha-elementor-products-search input.kentha-elementor-products-search__input' => 'background-color: {{VALUE}} !important;',
					]
				]
			);
			$this->add_control(
				'color_text',
				[
					'label' => esc_html__( 'Text color', 'elementor-kentha' ),
					'type' => \Elementor\Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .kentha-elementor-products-search input.kentha-elementor-products-search__input' => 'color: {{VALUE}} !important;',
						'{{WRAPPER}} .kentha-elementor-products-search .input-field i' => 'color: {{VALUE}} !important;',
					]
				]
			);
			$this->add_responsive_control(
				'k_padding',
				[
					'label' => __( 'Padding', 'elementor' ),
					'type' => Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', 'em', '%' ],
					'selectors' => [
						'{{WRAPPER}} .kentha-elementor-products-search input.kentha-elementor-products-search__input' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);


			
			$this->add_responsive_control(
				'iconpadding',
				[
					'label' => esc_html__( 'Icon position', 'elementor-kentha' ),
					'type' => \Elementor\Controls_Manager::SLIDER,
					'range' => [
						'px' => [
							'min' => 0,
							'max' => 60,
						],
					],
					'devices' => [ 'desktop', 'tablet', 'mobile' ],
					'desktop_default' => [
						'size' => 5,
						'unit' => 'px',
					],
					'tablet_default' => [
						'size' => 5,
						'unit' => 'px',
					],
					'mobile_default' => [
						'size' => 5,
						'unit' => 'px',
					],
					'selectors' => [
						'{{WRAPPER}} .kentha-elementor-products-search .input-field .prefix' => 'padding-top: {{SIZE}}{{UNIT}} !important; padding-left: {{SIZE}}{{UNIT}} !important;',
					],
				]
			);
			$this->add_responsive_control(
				'btn-radius',
				[
					'label' => esc_html__( 'Border-radius', 'elementor-kentha' ),
					'type' => \Elementor\Controls_Manager::SLIDER,
					'range' => [
						'px' => [
							'min' => 0,
							'max' => 140,
						],
					],
					'devices' => [ 'desktop', 'tablet', 'mobile' ],
					'desktop_default' => [
						'size' => 0,
						'unit' => 'px',
					],
					'tablet_default' => [
						'size' => 0,
						'unit' => 'px',
					],
					'mobile_default' => [
						'size' => 0,
						'unit' => 'px',
					],
					'selectors' => [
						'{{WRAPPER}}  .kentha-elementor-products-search input.kentha-elementor-products-search__input' => 'border-radius: {{SIZE}}{{UNIT}};',
					],
				]
			);
			$this->add_responsive_control(
				'fsize',
				[
					'label' => esc_html__( 'Font size', 'elementor-kentha' ),
					'type' => \Elementor\Controls_Manager::SLIDER,
					'range' => [
						'px' => [
							'min' => 12,
							'max' => 60,
						],
					],
					'devices' => [ 'desktop', 'tablet', 'mobile' ],
					'desktop_default' => [
						'size' => 15,
						'unit' => 'px',
					],
					'tablet_default' => [
						'size' => 15,
						'unit' => 'px',
					],
					'mobile_default' => [
						'size' => 15,
						'unit' => 'px',
					],
					'selectors' => [
						'{{WRAPPER}} .kentha-elementor-products-search .input-field input[type=text]' => 'font-size: {{SIZE}}{{UNIT}} !important;',
					],
				]
			);

			
		$this->end_controls_section();
	}

	/**
	 * Frontend
	 */
	protected function render() {
		$atts = $this->get_settings_for_display();
		extract( shortcode_atts( array(
			'class' => '',
			'placeholder' => 'Search: type and hit enter '
		), $atts ) );

		?>
		<div class="kentha-elementor-products-search  <?php echo esc_attr( $class ); ?>">
		<form method="get" class="form-horizontal qw-searchform" action="<?php echo esc_url( home_url( '/' ) ); ?>" role="search">
			<input type="hidden" name="post_type" value="product" />
			<div class="input-field">
				<i class="material-icons prefix">search</i>
				<input value="<?php echo esc_attr(get_search_query()); ?>" name="s" class="kentha-elementor-products-search__input qt-input-fullwidth" placeholder="<?php echo esc_attr($placeholder); ?>" type="text" />
			</div>
		</form>
		</div>
		<?php 
	}
	
	/* Update 2021 09 15 */
protected function content_template() {}
}