<?php
/**
 * @source  https://developers.elementor.com/elementor-controls/
 * @author  Kentha
 * @package  Elementor Kentha
 * @version  1.0.0
 */


namespace KenthaElementor\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Core\Schemes\Typography;
use Elementor\Group_Control_Border;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly


class KenthaElementorButtonRadio extends Widget_Base {
	public function get_name() {
		return 'kentha-elementor-button-radio'; // need to use same ID in the script js
	}
	public function get_title() {
		return esc_html__( 'Play radio button', 'elementor-kentha' );
	}
	public function get_icon() {
		return 'kentha-elementor-icons icon-qtelicon-button';
	}
	public function get_categories() {
		return [ 'aaa-kentha' ]; // needs to be registered in _plugin.php
	}

	protected function register_controls() {
		$this->start_controls_section(
			'section_button',
			[
				'label' => esc_html__( 'Button', 'elementor-kentha' ),
			]
		);

			/**
			 * ====================
			 * chose function
			 * ====================
			 */

			$this->add_control(
				'text',
				[
					'label' => esc_html__( 'Button label', 'elementor-kentha' ),
					'type' => Controls_Manager::TEXT,
					'default' => esc_html__('Click here', 'elementor-kentha')
				]
			);


			// Play radio ====================== 

			$this->add_control(
				'play_radio_id',
				[
					'label' => esc_html__( 'Radio channel', 'elementor-kentha' ),
					'type' => \Elementor\Controls_Manager::SELECT2,
					'label_block' => true,
					'multiple' => false,
					'options' => elementor_kentha_autocomplete('radiochannel'),
				]
			);

			
			// ==== function end ==========


			$this->add_control(
				'btnstyle',
				[
					'label' => esc_html__( 'Button style', 'elementor-kentha' ),
					'type' => \Elementor\Controls_Manager::SELECT,
					'multiple' => false,
					'options' =>[
						'qt-btn-default' => esc_html__( "Default", "kentha"),
						'qt-btn-primary' 	=>	esc_html__( "Primary", "elementor-kentha"),
						'qt-btn-secondary'	=>	esc_html__( "Secondary", "elementor-kentha"),
						'qt-btn-ghost'	=>	esc_html__( "Ghost", "elementor-kentha"),
					]
				]
			);


			$this->add_control(
				'alignment',
				[
					'label' => esc_html__( 'Alignment', 'elementor-kentha' ),
					'type' => \Elementor\Controls_Manager::SELECT,
					'multiple' => false,
					'options' =>[
						'' => esc_html__( "Default", "kentha"),
						'alignleft' 	=>	esc_html__( "Left", "elementor-kentha"),
						'alignright'	=>	esc_html__( "Right", "elementor-kentha"),
						'aligncenter'	=>	esc_html__( "Center", "elementor-kentha"),
					]
				]
			);

			$this->add_responsive_control(
				'btn-size',
				[
					'label' => esc_html__( 'Size', 'elementor-kentha' ),
					'type' => \Elementor\Controls_Manager::SLIDER,
					'range' => [
						'px' => [
							'min' => 0,
							'max' => 132,
						],
					],
					'devices' => [ 'desktop', 'tablet', 'mobile' ],
					'desktop_default' => [
						'size' => 13,
						'unit' => 'px',
					],
					'tablet_default' => [
						'size' => 13,
						'unit' => 'px',
					],
					'mobile_default' => [
						'size' => 13,
						'unit' => 'px',
					],
					'selectors' => [
						'{{WRAPPER}} .kentha-btn' => 'font-size: {{SIZE}}{{UNIT}};',
					],
				]
			);

			$this->add_group_control(
				\Elementor\Group_Control_Typography::get_type(),
				[
					'name' => 'kentha-txt-typo',
					'label' => __( 'Typography','kentha-elementor'),
					'scheme' => Typography::TYPOGRAPHY_1,
					'selector' => '{{WRAPPER}} .kentha-btn span'
				]
			);
			$this->add_responsive_control(
				'btn-size-icon',
				[
					'label' => esc_html__( 'Icon size', 'elementor-kentha' ),
					'type' => \Elementor\Controls_Manager::SLIDER,
					'range' => [
						'px' => [
							'min' => 0,
							'max' => 250,
						],
					],
					'devices' => [ 'desktop', 'tablet', 'mobile' ],
					'desktop_default' => [
						'size' => 24,
						'unit' => 'px',
					],
					'tablet_default' => [
						'size' => 24,
						'unit' => 'px',
					],
					'mobile_default' => [
						'size' => 24,
						'unit' => 'px',
					],
					'selectors' => [
						'{{WRAPPER}} .kentha-btn i' => 'font-size: {{SIZE}}{{UNIT}};',
					],
				]
			);

			$this->add_responsive_control(
				'icon-spacing',
				[
					'label' => esc_html__( 'Icon spacing from text', 'elementor-kentha' ),
					'type' => \Elementor\Controls_Manager::SLIDER,
					'range' => [
						'px' => [
							'min' => 0,
							'max' => 50,
						],
					],
					'devices' => [ 'desktop', 'tablet', 'mobile' ],
					'desktop_default' => [
						'size' => 5,
						'unit' => 'px',
					],
					'tablet_default' => [
						'size' => 5,
						'unit' => 'px',
					],
					'mobile_default' => [
						'size' => 5,
						'unit' => 'px',
					],
					'selectors' => [
						'{{WRAPPER}} .kentha-btn i' => 'margin-right: {{SIZE}}{{UNIT}};',
					],
				]
			);

			$this->add_responsive_control(
				'btn-padding',
				[
					'label' => __( 'Padding', 'kentha-elementor' ),
					'type' => Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', 'em', '%' ],
					'default' =>[
						'top' => 14,
						'right' => 14,
						'bottom' => 14,
						'left' => 14,
						'isLinked' => true,
						],
					'selectors' => [
						'{{WRAPPER}} .qt-btn' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;width:auto;',
					],
				]
			);
			$this->add_responsive_control(
				'btn-radius',
				[
					'label' => esc_html__( 'Border-radius', 'elementor-kentha' ),
					'type' => \Elementor\Controls_Manager::SLIDER,
					'range' => [
						'px' => [
							'min' => 0,
							'max' => 300,
						],
					],
					'devices' => [ 'desktop', 'tablet', 'mobile' ],
					'desktop_default' => [
						'size' => 2,
						'unit' => 'px',
					],
					'tablet_default' => [
						'size' => 2,
						'unit' => 'px',
					],
					'mobile_default' => [
						'size' => 2,
						'unit' => 'px',
					],
					'selectors' => [
						'{{WRAPPER}} .kentha-btn' => 'border-radius: {{SIZE}}{{UNIT}};',
					],
				]
			);
			
			

		$this->end_controls_section();

		/**
		 * Colors
		 */
		$this->start_controls_section(
			'section_button_col',
			[
				'label' => esc_html__( 'Colors', 'elementor-kentha' ),
			]
		);
			$this->add_control(
				'kentha-btn-bg',
				[
					'label' => esc_html__( 'Background', 'elementor-kentha' ),
					'type' => \Elementor\Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .kentha-btn' => 'background-color: {{VALUE}} !important;',
					],
				]
			);
			$this->add_control(
				'kentha-btn-txt',
				[
					'label' => esc_html__( 'Text color', 'elementor-kentha' ),
					'type' => \Elementor\Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .kentha-btn' => 'color: {{VALUE}} !important;',
					]
				]
			);

			$this->add_group_control(
				\Elementor\Group_Control_Border::get_type(),
				[
					'name' => 'border',
					'label' => esc_html__( 'Border', 'kentha-elementor' ),
					'selector' => '{{WRAPPER}} .kentha-btn',
				]
			);

			

		$this->end_controls_section();

		/**
		 * Colors hover
		 */
		$this->start_controls_section(
			'section_button_col_h',
			[
				'label' => esc_html__( 'Colors hover', 'elementor-kentha' ),
			]
		);
			$this->add_control(
				'kentha-btn-bgh',
				[
					'label' => esc_html__( 'Background hover', 'elementor-kentha' ),
					'type' => \Elementor\Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .kentha-btn:hover' => 'background-color: {{VALUE}} !important;',
					]
				]
			);
			$this->add_control(
				'kentha-btn-bch',
				[
					'label' => esc_html__( 'Border hover', 'elementor-kentha' ),
					'type' => \Elementor\Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .kentha-btn:hover' => 'border-color: {{VALUE}} !important;',
					]
				]
			);
			$this->add_control(
				'kentha-btn-txthov',
				[
					'label' => esc_html__( 'Text color hover', 'elementor-kentha' ),
					'type' => \Elementor\Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .kentha-btn:hover' => 'color: {{VALUE}} !important;',
					]
				]
			);

		$this->end_controls_section();
	}

	/**
	 * Frontend
	 */
	protected function render() {
		$atts = $this->get_settings_for_display();
		extract( shortcode_atts( array(
			'include_by_id' => false,
			'play_radio_id' => false,
			'text' => esc_html__('Click here', 'kentha'),
			'btnstyle' => 'qt-btn-default',
			'link' => '#',
			'alignment' => '',
		), $atts ) );
		$attributes = [];
		$noajax = '';
		$play = false;


		if( $kentha_btnfn == 'playalbum' && $include_by_id ){
			$play = true;
			$url = add_query_arg('qt_json', '1',  get_the_permalink( $include_by_id));
			$attributes[] = 'data-kenthaplayer-addrelease="' . $url .'"';
			$attributes[] = 'data-playnow="1"';
			$noajax = 'qwNoAjax';
		}

		if($play_radio_id ){

			$play = true;
			$url = add_query_arg('qt_json', '1',  get_the_permalink( $include_by_id));
			$attributes[] = 'data-kenthaplayer-addrelease="' . $url .'"';
			$attributes[] = 'data-playnow="1"';
			$noajax = 'qwNoAjax';

			$id = $play_radio_id;
			$mp3_stream_url = get_post_meta( $id, 'mp3_stream_url', true );
			$subtitle = get_post_meta($id, 'qt_radio_subtitle',true);
			if( $mp3_stream_url ){
				$icon = get_post_meta($id, 'qt_player_icon', true );
				$thumb = get_the_post_thumbnail_url( $id, 'medium' );

				
				$attributes = implode(' ', $attributes);

				

				?>
				<ul class="kentha-elementor-playbutton-radio">
					<li class="qtmusicplayer-trackitem <?php if( $alignment == 'aligncenter' || $alignment == 'center' ){  ?>aligncenter<?php  }  ?>">
						<span class="qt-play qt-link-sec qtmusicplayer-play-btn qwNoAjax btn kentha-btn qt-btn <?php echo esc_attr($btnstyle); ?> <?php  echo esc_attr( $alignment ); ?>" 
						data-qtmplayer-type="radio"
						data-qtmplayer-cover="<?php echo esc_url($thumb); ?>" 
						data-qtmplayer-file="<?php echo esc_url( $mp3_stream_url ); ?>" 
						data-qtmplayer-title="<?php echo esc_attr( get_the_title() ); ?>" 
						data-qtmplayer-artist="<?php  echo esc_attr( $subtitle ); ?>" 
						data-qtmplayer-album="<?php echo esc_attr(get_the_title()); ?>" 
						data-qtmplayer-link="<?php the_permalink(); ?>" 
						data-qtmplayer-buylink="" 
						data-qtmplayer-icon="<?php echo esc_attr($icon); ?>" 

						
						data-radiochannel
						data-host="<?php echo esc_attr(get_post_meta( $id, 'qtradiofeedHost',true )); ?>"
						data-port="<?php echo esc_attr(get_post_meta( $id, 'qtradiofeedPort',true )); ?>"
						data-ssl="<?php echo esc_attr(get_post_meta( $id, 'qtradiofeedSSL',true )); ?>"
						data-icecasturl="<?php echo esc_attr(get_post_meta( $id, 'qticecasturl',true )); ?>"
						data-icecastmountpoint="<?php echo esc_attr(get_post_meta( $id, 'qticecastMountpoint',true )); ?>"
						data-radiodotco="<?php echo esc_attr(get_post_meta( $id, 'qtradiodotco',true )); ?>"
						data-airtime="<?php echo esc_attr(get_post_meta( $id, 'qtairtime',true )); ?>"
						data-radionomy="<?php echo esc_attr(get_post_meta( $id, 'qtradionomy',true )); ?>"
						data-textfeed="<?php echo esc_attr(get_post_meta( $id, 'qttextfeed',true )); ?>"
						data-channel="<?php echo esc_attr(get_post_meta( $id, 'qtradiofeedChannel',true )); ?>"

						><i class='material-icons'>play_circle_filled</i><span><?php echo esc_html($text); ?></span>
					</li>
				</ul>
				<?php
					if($alignment == 'aligncenter'){ 
					?></p><?php 
				} 

			}


		} else {
			echo 'Please select radio channel';
		}




	}
	
	/* Update 2021 09 15 */
protected function content_template() {}
}