<?php
/**
 * @source  https://developers.elementor.com/elementor-controls/
 * @author  Pro.Radio
 * @package  Elementor Kentha
 * @version  1.0.0
 */


namespace KenthaElementor\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Core\Schemes\Typography;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly


class KenthaElementorRadiofeed extends Widget_Base {
	public function get_name() {
		return 'kentha-elementor-radiofeed'; // need to use same ID in the script js
	}
	public function get_title() {
		return esc_html__( 'Radio feed titles', 'kentha-elementor' );
	}
	public function get_icon() {
		return 'kentha-elementor-icons icon-qtelicon-radio-feed';
	}
	public function get_categories() {
		return [ 'aaa-kentha' ]; // needs to be registered in _plugin.php
	}

	// Javascript
	public function __construct($data = [], $args = null) {
      parent::__construct($data, $args);
      wp_register_script( 'kentha-elementor-radiofeed', plugins_url( '/radiofeed.js', __FILE__ ), [ 'elementor-frontend' ], '1.0.0', true );
   	}
 	public function get_script_depends() {
	     return [ 'kentha-elementor-radiofeed' ];
	}


	protected function register_controls() {
		$this->start_controls_section(
			'section_button',
			[
				'label' => esc_html__( 'Settings', 'kentha-elementor' ),
			]
		);
			$this->add_control(
				'intro',
				[
					'label' => esc_html__( 'Important Note', 'kentha-elementor' ),
					'raw' => __( '<h2><strong>This text becomes visible only after playing a radio stream with valid song feed details.</strong></h2>', 'kentha-elementor' ),
					'type' => Controls_Manager::RAW_HTML,
				]
			);
			$this->add_control(
				'kentha-txt',
				[
					'label' => esc_html__( 'Text color', 'elementor-kentha' ),
					'type' => \Elementor\Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .qt-kentharadio-songtitle-shortcode' => 'color: {{VALUE}} !important;',
					]
				]
			);
			$this->add_group_control(
				\Elementor\Group_Control_Typography::get_type(),
				[
					'name' => 'kentha-txt-typo',
					'label' => __( 'Typography','vice-elementor'),
					'scheme' => Typography::TYPOGRAPHY_1,
					'selector' => '{{WRAPPER}} .qt-kentharadio-songtitle-shortcode'
				]
			);

			$this->add_control(
				'title',
				[
					'label' => esc_html__( 'Title', 'kentha-elementor' ),
					'default' => esc_html__( 'Now playing:', 'kentha-elementor' ),
					'description' => esc_html__( 'Label for the song title', 'kentha-elementor' ),
					'type' => Controls_Manager::TEXT,
				]
			);
			
			$this->add_control(
				'tag',
				[
					'label' 	=> esc_html__( 'Container tag', 'kentha-elementor' ),
					'type' 		=> \Elementor\Controls_Manager::SELECT,
					'default' 	=> 'p',
					'options' 	=>[
						'' 			=> esc_html__('No container', 'kentha-elementor'), 
						'h1' 		=> esc_html__('Heading 1', 'kentha-elementor'), 
						'h2' 		=> esc_html__('Heading 2', 'kentha-elementor'), 
						"h3" 		=> esc_html__('Heading 3', 'kentha-elementor'), 
						"h4" 		=> esc_html__('Heading 4', 'kentha-elementor'), 
						"h5" 		=> esc_html__('Heading 5', 'kentha-elementor'), 
						"h6" 		=> esc_html__('Heading 6', 'kentha-elementor'), 
						"p" 		=> esc_html__('Paragraph', 'kentha-elementor'), 
					]
				]
			);
			$this->add_control(
				'align',
				[
					'label' 	=> esc_html__( 'Align', 'kentha-elementor' ),
					'type' 		=> \Elementor\Controls_Manager::SELECT,
					'default' => 'center',
					'options' =>[
						'center'	=> esc_html__('center', 'kentha' ),
						'left'		=> esc_html__('left', 'kentha' ),
						'right'		=> esc_html__('right', 'kentha' ),
						'inline'	=> esc_html__('inline', 'kentha' ),
					]
				]
			);
			

			
		$this->end_controls_section();
	}

	/**
	 * Frontend
	 */
	protected function render() {
		if(function_exists('qt_kentharadio_short_songtitle')){
			echo qt_kentharadio_short_songtitle( $this->get_settings_for_display() );
		}
	}
	
	/* Update 2021 09 15 */
protected function content_template() {}
}