<?php
/**
 * @source  https://developers.elementor.com/elementor-controls/
 * @author  Pro.Radio
 * @package  Elementor Kentha
 * @version  1.0.0
 */


namespace KenthaElementor\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Core\Schemes\Typography;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

require_once( __DIR__ . '/release-small-function.php' );

class KenthaElementorReleaseSmall extends Widget_Base {
	public function get_name() {
		return 'kentha-elementor-releases-small'; // need to use same ID in the script js
	}
	public function get_title() {
		return esc_html__( 'Release grid small', 'kentha-elementor' );
	}
	public function get_icon() {
		return 'kentha-elementor-icons icon-qtelicon-release-grid-small';
	}
	public function get_categories() {
		return [ 'aaa-kentha' ]; // needs to be registered in _plugin.php
	}

	// JS ============================
	/*public function __construct($data = [], $args = null) {
      parent::__construct($data, $args);
      wp_register_script( 'kentha-elementor-releases-small', plugins_url( '/release-small.js', __FILE__ ), [ 'elementor-frontend' ], '1.0.0', true );
   	}
 	public function get_script_depends() {
	     return [ 'kentha-elementor-releases-small' ];
	}*/
	// ===============================


	protected function register_controls() {

		/**
		 * ======================================
		 * Section:
		 * Query parameters
		 * ======================================
		 */
		$this->start_controls_section(
			'kentha_elementor_section_query_global',
			[
				'label' => esc_html__( 'Query', 'kentha-elementor' ),
			]
		);

			$this->add_control(
				'kel_tax_filter',
				[
					'label' => esc_html__( 'Category filters', 'kentha-elementor' ),
					'type' => \Elementor\Controls_Manager::SELECT2,
					'label_block' => true,
					'multiple' => true,
					'options' => kentha_elementor_get_terms_array("genre")
				]
			);
		// Important::::::::::::::::::::::::::::::::::::
		// Fields added by query-fields.php
		// :::::::::::::::::::::::::::::::::::::::::::::
		$this->end_controls_section();



		$this->start_controls_section(
			'kentha_elementor_section',
			[
				'label' => esc_html__( 'Settings', 'kentha-elementor' ),
			]
		);	

			$this->add_control(
				'iprd',
				[
					'label' => esc_html__( 'Columns per row', 'kentha-elementor' ).' '.esc_html__( 'Desktop', 'kentha-elementor' ),
					'type' => \Elementor\Controls_Manager::SELECT,
					'default' => 3,
					'options' =>[
						1 => esc_html__( "1", "kentha-elementor"),
						2 => esc_html__( "2", "kentha-elementor"),
						3 => esc_html__( "3", "kentha-elementor"),
						4 => esc_html__( "4", "kentha-elementor"),
						6 => esc_html__( "6", "kentha-elementor"),
					]
				]
			);
			$this->add_control(
				'iprt',
				[
					'label' => esc_html__( 'Columns per row', 'kentha-elementor' ).' '.esc_html__( 'Tablet', 'kentha-elementor' ),
					'type' => \Elementor\Controls_Manager::SELECT,
					'default' => 2,
					'options' =>[
						1 => esc_html__( "1", "kentha-elementor"),
						2 => esc_html__( "2", "kentha-elementor"),
						3 => esc_html__( "3", "kentha-elementor"),
						4 => esc_html__( "4", "kentha-elementor"),
					]
				]
			);
			$this->add_control(
				'iprm',
				[
					'label' => esc_html__( 'Columns per row', 'kentha-elementor' ).' '.esc_html__( 'Mobile', 'kentha-elementor' ),
					'type' => \Elementor\Controls_Manager::SELECT,
					'default' => 2,
					'options' =>[
						1 => esc_html__( "1", "kentha-elementor"),
						2 => esc_html__( "2", "kentha-elementor"),
						3 => esc_html__( "3", "kentha-elementor"),
						4 => esc_html__( "4", "kentha-elementor"),
					]
				]
			);
		// Fields added by query-fields.php
		$this->end_controls_section();
	}
	/**
	 * Frontend
	 */
	protected function render() {
		$atts = $this->get_settings_for_display();
		if(array_key_exists('kel_tax_filter', $atts)){
			if(is_array($atts['kel_tax_filter'])) {
				$atts['tax_filter'] = implode(',', $atts['kel_tax_filter']);
			}
		}

		if(function_exists('kentha_elementor_release_small_function')){
			echo kentha_elementor_release_small_function( $atts );
		}
	}
	/* Update 2021 09 15 */
protected function content_template() {}
}