<?php
/**
 * @source  https://developers.elementor.com/elementor-controls/
 * @author  Pro.Radio
 * @package  Elementor Kentha
 * @version  1.0.0
 */


namespace KenthaElementor\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly
require_once( __DIR__ . '/releases-large-function.php' );

class KenthaElementorReleasesLarge extends Widget_Base {
	public function get_name() {
		return 'kentha-elementor-releases-large'; // need to use same ID in the script js
	}
	public function get_title() {
		return esc_html__( 'Release featured slider', 'kentha-elementor' );
	}
	public function get_icon() {
		return 'kentha-elementor-icons icon-qtelicon-shows-slider';
	}
	public function get_categories() {
		return [ 'aaa-kentha' ]; // needs to be registered in _plugin.php
	}


	// JS ============================	
	public function __construct($data = [], $args = null) {
      parent::__construct($data, $args);
      wp_register_script( 'kentha-elementor-releases-large', plugins_url( '/releases-large.js', __FILE__ ), [ 'elementor-frontend' ], '1.0.0', true );
   	}
 	public function get_script_depends() {
	     return [ 'kentha-elementor-releases-large' ];
	}
	// ===============================

	protected function register_controls() {


		/**
		 * ======================================
		 * Section:
		 * Carousel parameters
		 * ======================================
		 */
		$this->start_controls_section(
			'kentha_elementor_section_carousel_featured',
			[
				'label' => esc_html__( 'Settings', 'kentha-elementor' ),
			]
		);

			$this->add_control(
				'title',
				[
					'label' => esc_html__( 'Title', 'elementor-kentha' ),
					'type' => Controls_Manager::TEXT,
				]
			);
		
			$this->add_control(
			'design',
			[
				'label' => esc_html__( 'Design', 'kentha-elementor' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'multiple' => false,
				'options' =>[
					"default" => esc_html__( "Default", 'kentha-elementor' ),
					"center" => esc_html__( "Center", 'kentha-elementor' ),
				]
			]
		);
		
	



		$this->add_control(
			'autoplay',
			[
				'label' => esc_html__( 'Autoplay', 'kentha-elementor' ),
				'type' => Controls_Manager::SWITCHER,
				'return_value' => 'true',
			]
		);

		
		$this->add_control(
			'pause_on_hover',
			[
				'label' => esc_html__( 'Pause on hover', 'kentha-elementor' ),
				'type' => Controls_Manager::SWITCHER,
				'return_value' => 'true',
			]
		);
	
		$this->add_control(
			'nav',
			[
				'label' => esc_html__( 'Arrows', 'kentha-elementor' ),
				'type' => Controls_Manager::SWITCHER,
				'label_on' => esc_html__('Show', 'kentha-elementor' ),
				'label_off' => esc_html__('Hide', 'kentha-elementor' ),
				'return_value' => 'true',
				'default' => 'true'
			]
		);
		$this->add_control(
			'dots',
			[
				'label' => esc_html__( 'Dots', 'kentha-elementor' ),
				'type' => Controls_Manager::SWITCHER,
				'label_on' => esc_html__('Show', 'kentha-elementor' ),
				'label_off' => esc_html__('Hide', 'kentha-elementor' ),
				'return_value' => 'true',
				'default' => 'true'
			]
		);
			$this->end_controls_section();



		/**
		 * ======================================
		 * Section:
		 * Query parameters
		 * ======================================
		 */
		$this->start_controls_section(
			'kentha_elementor_section_query_global',
			[
				'label' => esc_html__( 'Query', 'kentha-elementor' ),
			]
		);

			$this->add_control(
				'kel_tax_filter',
				[
					'label' => esc_html__( 'Category filters', 'kentha-elementor' ),
					'type' => \Elementor\Controls_Manager::SELECT2,
					'label_block' => true,
					'multiple' => true,
					'options' => kentha_elementor_get_terms_array("genre")
				]
			);
		// Important::::::::::::::::::::::::::::::::::::
		// Fields added by query-fields.php
		// :::::::::::::::::::::::::::::::::::::::::::::
		$this->end_controls_section();

		
	}
	/**
	 * Frontend
	 */
	protected function render() {
		$atts = $this->get_settings_for_display();
		if(array_key_exists('kel_tax_filter', $atts)){
			if(is_array($atts['kel_tax_filter'])) {
				$atts['tax_filter'] = implode(',', $atts['kel_tax_filter']);
			}
		}
		if(function_exists('kentha_elementor_release_large_function')){
			echo kentha_elementor_release_large_function( $atts );
		}
	}
	/* Update 2021 09 15 */
protected function content_template() {}
}