<?php
/**
 * @source  https://developers.elementor.com/elementor-controls/
 * @author  Pro.Radio
 * @package  Elementor Kentha
 * @version  1.0.0
 */


namespace KenthaElementor\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Core\Schemes\Typography;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly


class KenthaElementorSectionCaption extends Widget_Base {
	public function get_name() {
		return 'kentha-elementor-section-caption'; // need to use same ID in the script js
	}
	public function get_title() {
		return esc_html__( 'Section caption FX', 'kentha-elementor' );
	}
	public function get_icon() {
		return 'kentha-elementor-icons icon-qtelicon-section-caption';
	}
	public function get_categories() {
		return [ 'aaa-kentha' ]; // needs to be registered in _plugin.php
	}

	// Javascript
	public function __construct($data = [], $args = null) {
	  parent::__construct($data, $args);
	  wp_register_script( 'elementor-kentha-section-caption', plugins_url( '/section-caption.js', __FILE__ ), [ 'elementor-frontend' ], '1.0.0', true );
	}
	public function get_script_depends() {
		 return [ 'elementor-kentha-section-caption' ];
	}

	protected function register_controls() {


		$this->start_controls_section(
			'section_content',
			[
				'label' => esc_html__( 'Content', 'kentha-elementor' ),
			]
		);
			$this->add_control(
				'text',
				[
					'label' => esc_html__( 'Caption', 'kentha-elementor' ),
					'type' => Controls_Manager::TEXT,
				]
			);
			$this->add_responsive_control(
				'kentha-captionsize',
				[
					'label' => esc_html__( 'Caption size', 'elementor-kentha' ),
					'type' => \Elementor\Controls_Manager::SLIDER,
					'range' => [
						'px' => [
							'min' => 20,
							'max' => 130,
						],
					],
					'devices' => [ 'desktop', 'tablet', 'mobile' ],
					'selectors' => [
						'{{WRAPPER}} .qt-capfont ' => 'font-size: {{SIZE}}{{UNIT}};',
						'{{WRAPPER}} .qt-txtfx ' => 'font-size: {{SIZE}}{{UNIT}};',
					],
				]
			);
			
		$this->end_controls_section();


		/**
		 * ============================================
		 * Section 
		 * Intro
		 * ============================================
		 */
		$this->start_controls_section(
			'section_intro',
			[
				'label' => esc_html__( 'Intro effect', 'kentha-elementor' ),
			]
		);	
			
			$this->add_control(
				'fx',
				[
					'label' => esc_html__( 'Effect', "elementor-kentha" ),
					'type' => \Elementor\Controls_Manager::SELECT,
					'multiple' => false,
					'default' => 'oslo',
					'options' =>[
						"oslo" 		=> esc_html__( "Oslo", "elementor-kentha"),
						 "tokyo" 	=> esc_html__( "Tokyo", "elementor-kentha"),
						"london" 	=> esc_html__( "London", "elementor-kentha"),
						"paris" 	=> esc_html__( "Paris", "elementor-kentha"),
						"ibiza" 	=> esc_html__( "Ibiza", "elementor-kentha"),
						"newyork" 	=> esc_html__( "New York", "elementor-kentha")
					]
				]
			);
			$this->add_control(
				'color1',
				[
					'label' => esc_html__( 'Color 1', 'kentha-elementor' ),
					'type' => \Elementor\Controls_Manager::COLOR,
					'default' => '#dedede',
				]
			);
			$this->add_control(
				'color2',
				[
					'label' => esc_html__( 'Color 2', 'kentha-elementor' ),
					'type' => \Elementor\Controls_Manager::COLOR,
					'default' => '#999999',
				]
			);
			$this->add_control(
				'color3',
				[
					'label' => esc_html__( 'Color 3', 'kentha-elementor' ),
					'type' => \Elementor\Controls_Manager::COLOR,
					'default' => '#ff0000',
				]
			);
		$this->end_controls_section();

	}

	/**
	 * Frontend
	 */
	protected function render() {
		$atts = $this->get_settings_for_display();
		echo kentha_short_textfx( $atts );
	}

	
	/* Update 2021 09 15 */
protected function content_template() {}
}