<?php
/**
 * @source  https://developers.elementor.com/elementor-controls/
 * @author  Pro.Radio
 * @package  Elementor Kentha
 * @version  1.0.0
 */


namespace KenthaElementor\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Core\Schemes\Typography;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly


class KenthaElementorUpcomingShowsCarousel extends Widget_Base {
	public function get_name() {
		return 'kentha-elementor-upcoming-shows-carousel'; // need to use same ID in the script js
	}
	public function get_title() {
		return esc_html__( 'Upcoming shows carousel', 'kentha-elementor' );
	}
	public function get_icon() {
		return 'kentha-elementor-icons icon-qtelicon-shows-carousel';
	}
	public function get_categories() {
		return [ 'aaa-kentha' ]; // needs to be registered in _plugin.php
	}
	// JS ============================	
	public function __construct($data = [], $args = null) {
      parent::__construct($data, $args);
      wp_register_script( 'kentha-elementor-upcoming-shows-carousel', plugins_url( '/upcoming-shows-carousel.js', __FILE__ ), [ 'elementor-frontend' ], '1.0.0', true );
   	}
 	public function get_script_depends() {
	     return [ 'kentha-elementor-upcoming-shows-carousel' ];
	}
	// ===============================
	protected function register_controls() {
		/**
		 * ======================================
		 * Section:
		 * Slider parameters
		 * ======================================
		 */
		$this->start_controls_section(
			'kentha_elementor_section_carousel',
			[
				'label' => esc_html__( 'Settings', 'kentha-elementor' ),
			]
		);
			$this->add_control(
				'title',
				[
					'label' => esc_html__( 'Title', 'elementor-kentha' ),
					'type' => Controls_Manager::TEXT,
				]
			);

			$this->add_control(
				'design',
				[
					'label' => esc_html__( 'Design', 'kentha-elementor' ),
					'type' => \Elementor\Controls_Manager::SELECT,
					'multiple' => false,
					'options' =>[
						"default" => esc_html__( "Default", 'kentha-elementor' ),
						"center" => esc_html__( "Center", 'kentha-elementor' ),
					]
				]
			);

		// Important::::::::::::::::::::::::::::::::::::
		// Fields added by carousel-fields.php
		// :::::::::::::::::::::::::::::::::::::::::::::
		$this->end_controls_section();

		/**
		 * ======================================
		 * Section:
		 * Query parameters
		 * ======================================
		 */
		
		$this->start_controls_section(
			'kentha_elementor_query',
			[
				'label' => esc_html__( 'Filters', 'kentha-elementor' ),
			]
		);

			$this->add_control(
				'quantity',
				[
					'label' => esc_html__( 'Max items', 'kentha-elementor' ),
					'type' => Controls_Manager::NUMBER,
					'min' => 3,
					'max' => 16,
					'step' => 1,
					'default' => 9,
				]
			);
			$this->add_control(
				'schedulefilter',
				[
					'label' => esc_html__( 'Schedule filters', 'kentha-elementor' ),
					'type' => \Elementor\Controls_Manager::SELECT2,
					'label_block' => true,
					'options' => kentha_elementor_get_terms_array( 'schedulefilter' )
				]
			);
			// Important::::::::::::::::::::::::::::::::::::
			// Fields added by query-fields.php
			// :::::::::::::::::::::::::::::::::::::::::::::
		$this->end_controls_section();
	}
	/**
	 * Frontend
	 */
	protected function render() {
		$atts = $this->get_settings_for_display();
		if(array_key_exists('schedulefilter', $atts)){
			if(is_array($atts['schedulefilter'])) {
				$atts['schedulefilter'] = implode(',', $atts['schedulefilter']);
			}
		}
		if(function_exists('qt_kentharadio_upcoming_carousel')){
			echo qt_kentharadio_upcoming_carousel( $atts );
		}
	}
	/* Update 2021 09 15 */
protected function content_template() {}
}