<?php
/**
 * @source  https://developers.elementor.com/elementor-controls/
 * @author  Pro.Radio
 * @package  Elementor Kentha
 * @version  1.0.0
 */


namespace KenthaElementor\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Core\Schemes\Typography;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly


class KenthaElementorUpcomingShowsSlider extends Widget_Base {
	public function get_name() {
		return 'kentha-elementor-upcoming-shows-slider'; // need to use same ID in the script js
	}
	public function get_title() {
		return esc_html__( 'Upcoming shows slider', 'kentha-elementor' );
	}
	public function get_icon() {
		return 'kentha-elementor-icons icon-qtelicon-shows-slider';
	}
	public function get_categories() {
		return [ 'aaa-kentha' ]; // needs to be registered in _plugin.php
	}
	// Javascript
	public function __construct($data = [], $args = null) {
      parent::__construct($data, $args);
      wp_register_script( 'kentha-elementor-upcoming-shows-slider', plugins_url( '/upcoming-shows-slider.js', __FILE__ ), [ 'elementor-frontend' ], '1.0.0', true );
   	}
 	public function get_script_depends() {
	     return [ 'kentha-elementor-upcoming-shows-slider' ];
	}


	protected function register_controls() {


		

		/**
		 * ======================================
		 * Section:
		 * Query parameters
		 * ======================================
		 */
		
		$this->start_controls_section(
			'kentha_elementor_query',
			[
				'label' => esc_html__( 'Filters', 'kentha-elementor' ),
			]
		);
			$this->add_control(
				'quantity',
				[
					'label' => esc_html__( 'Max items', 'kentha-elementor' ),
					'type' => Controls_Manager::NUMBER,
					'min' => 3,
					'max' => 6,
					'step' => 1,
					'default' => 5,
				]
			);
			$this->add_control(
				'schedulefilter',
				[
					'label' => esc_html__( 'Schedule filters', 'kentha-elementor' ),
					'type' => \Elementor\Controls_Manager::SELECT2,
					'label_block' => true,
					'options' => kentha_elementor_get_terms_array( 'schedulefilter' )
				]
			);
			// Important::::::::::::::::::::::::::::::::::::
			// Fields added by query-fields.php
			// :::::::::::::::::::::::::::::::::::::::::::::
		$this->end_controls_section();
	}
	/**
	 * Frontend
	 */
	protected function render() {
		$atts = $this->get_settings_for_display();
		if(array_key_exists('schedulefilter', $atts)){
			if(is_array($atts['schedulefilter'])) {
				$atts['schedulefilter'] = implode(',', $atts['schedulefilter']);
			}
		}
		if(function_exists('qt_kentharadio_upcoming_slider')){
			echo qt_kentharadio_upcoming_slider( $atts );
		}
	}
	/* Update 2021 09 15 */
protected function content_template() {}
}