<?php
/**
 * 
 * @package WordPress
 * @subpackage One Click Demo Import
 * @subpackage kentha
 * @version 1.0.0
 * Settings for the demo import
 * https://wordpress.org/plugins/one-click-demo-import/
 * 
*/
if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

add_filter( 'pt-ocdi/regenerate_thumbnails_in_content_import', '__return_false' );
add_filter( 'pt-ocdi/disable_pt_branding', '__return_true' );


/**
 * Disable thumbnail generation during import or it takes ages
 */
add_filter( 'pt-ocdi/regenerate_thumbnails_in_content_import', '__return_false' );

/**
 * Customize the popup width
 */
function kentha_ocdi_confirmation_dialog_options ( $options ) {
	return array_merge( $options, array(
		'width'       => 400,
		'dialogClass' => 'wp-dialog',
		'resizable'   => false,
		'height'      => 'auto',
		'modal'       => true,
	) );
}
add_filter( 'pt-ocdi/confirmation_dialog_options', 'kentha_ocdi_confirmation_dialog_options', 10, 1 );

/**
 * Customize the popup width
 */
if(!function_exists('kentha_ocdi_plugin_intro_text')){
	add_filter( 'pt-ocdi/plugin_intro_text', 'kentha_ocdi_plugin_intro_text' );
	function kentha_ocdi_plugin_intro_text( $default_text ) {
		ob_start();
		$admin_url =  admin_url( 'admin.php?page=kentha-welcome');
		?>
		<h2>Welcome to the Kentha Demo Import.</h2>
		<div class="kentha-ocdi-alert">
			<p><strong style="color: red">Demos depend on the page builder.</strong></p>
			<ul>
				<li>Demos 0-8: require <strong>WPBakery</strong></li>
				<li>Demos 9-10: require <strong>WPBakery and WooCommerce</strong>. Is not required to perform the WooCommerce setup wizard. Just install and come back here.</li>
				<li>Demos 11-25: require <strong>Elementor</strong></li>
			</ul>
			<?php
			/**
			* Define which demos to show.
			* This is made in a way to set Elementor as default if WPBakery is not installed already.
			*/
			if(function_exists('kentha_chosen_composer')){

				$chosen_composer = kentha_chosen_composer(); 

			
				/**
				 * Link including a force refresh
				 */
				$urladmin = admin_url( 'themes.php?page='.kentha_tgmpa_page() );
				$url = add_query_arg(
			        array(
			        	'tgm-refresh-iid' => '1',
			            'tgmpa-force' => '1',
			            'tgmpa-force-nonce2' => wp_create_nonce( 'tgmpa-force-nonce2' ),
			            'tgmpa-force-nonce' => wp_create_nonce( 'tgmpa-force-nonce' )
			        ),
			        $urladmin
			    );

				$missing_required = false;

				if( 'elementor' == $chosen_composer ) {
					if(defined('ELEMENTOR_VERSION')){
						?>
						<h3>Installed builder: Elementor</h3>
						<img class="kentha_ocdi_logoinstaller" src="<?php echo get_theme_file_uri('/inc/tgm-plugin-activation/img/composers-logos-elementor.png' ); ?>">
						<p>Change your preference in the <a href="<?php echo $admin_url; ?>">Kentha activation page.</a></p>
						<?php
					} else {
						?>
						<p style="color: red;">The selected editor (Elementor) is not active. Please <a href="<?php echo esc_url( $url ); ?>">complete the plugins installation</a> to proceed</p>
						<?php
						$missing_required = true;
					}
				} else if( 'wpbakery' == $chosen_composer ) {
					if(defined('WPB_VC_VERSION')){
						?>
							<h3>Installed builder: WPBakery</h3>
							<img class="kentha_ocdi_logoinstaller" src="<?php echo get_theme_file_uri('/inc/tgm-plugin-activation/img/composers-logos-wpbakery.png' ); ?>">
							<p>Change your preference in the <a href="<?php echo $admin_url; ?>">Kentha activation page.</a></p>

							<?php if ( !class_exists( 'WooCommerce' ) ) { ?>
							 <p style="font-size:19px;">WooCommerce is not installed. Please remember that <strong>WooCommerce demos 9 and 10</strong>  will appear only after installing the WooCommerce plugin.</p>
							 <?php } ?>
							<?php
						} else { ?>
							<p style="color: red;">The selected editor (WPBakery) is not active. Please <a href="<?php echo esc_url( $url ); ?>">complete the plugins installation</a> to proceed</p>
						<?php
						$missing_required = true;
					}
				}
			}
			?>
			<p>The impor process can take up to 5 minutes. If it gets stuck, you can repeat the import, until you see the confirmation text.</p>
			<p>In case of 5XX errors, please check the official documentation of the import plugin https://github.com/awesomemotive/one-click-demo-import/blob/master/docs/import-problems.md</p>
		</div>
		<?php 

		
		if(true == $missing_required){
			exit;
		}
		return ob_get_clean();
	}

}



if(function_exists('kentha_chosen_composer')){
	switch( kentha_chosen_composer() ){
		case 'elementor':
			if(defined('ELEMENTOR_VERSION')){
				require_once get_theme_file_path( '/inc/ocdi/ocdi-elementor.php' );
			}
			break;
		case 'wpbakery':
			if(defined('WPB_VC_VERSION')){
				require_once get_theme_file_path( '/inc/ocdi/ocdi-wpbakery.php' );
				
			}
			break;
	}
}
		